@@ -17,11 +17,21 @@
  * along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <src/ChangeType.h>
+#include <glib.h>
+#include <glib-object.h>
 
 
+#define DVB_TYPE_CHANGE_TYPE (dvb_change_type_get_type ())
+
+typedef enum  {
+	DVB_CHANGE_TYPE_ADDED = 0,
+	DVB_CHANGE_TYPE_DELETED = 1,
+	DVB_CHANGE_TYPE_UPDATED = 2
+} DVBChangeType;
+
 
 
+GType dvb_change_type_get_type (void);
 
 
 
