@@ -111,6 +111,7 @@ void dvb_channel_setup_dvb_source (DVBChannel* self, GstElement* source);
 static void dvb_channel_real_setup_dvb_source (DVBChannel* self, GstElement* source);
 char* dvb_channel_to_string (DVBChannel* self);
 static char* dvb_channel_real_to_string (DVBChannel* self);
+DVBChannel* dvb_channel_construct (GType object_type);
 DVBSchedule* dvb_schedule_new (DVBChannel* channel);
 DVBSchedule* dvb_schedule_construct (GType object_type, DVBChannel* channel);
 void dvb_channel_set_Sid (DVBChannel* self, guint value);
@@ -286,6 +287,13 @@ char* dvb_channel_to_string (DVBChannel* self) {
 }
 
 
+DVBChannel* dvb_channel_construct (GType object_type) {
+	DVBChannel * self;
+	self = g_object_newv (object_type, 0, NULL);
+	return self;
+}
+
+
 guint dvb_channel_get_Sid (DVBChannel* self) {
 	guint result;
 	g_return_val_if_fail (self != NULL, 0U);
@@ -474,7 +482,7 @@ DVBSchedule* dvb_channel_get_Schedule (DVBChannel* self) {
 char* dvb_channel_get_URL (DVBChannel* self) {
 	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	result = g_strdup_printf ("rtsp://localhost:8554/%u/%u", self->priv->_GroupId, dvb_channel_get_Sid (self));
+	result = g_strdup_printf ("rtsp://%s:8554/%u/%u", g_get_host_name (), self->priv->_GroupId, dvb_channel_get_Sid (self));
 	return result;
 }
 
