@@ -434,7 +434,7 @@ GstElement* dvb_player_thread_get_element (DVBPlayerThread* self, DVBChannel* ch
 			(sink_element == NULL) ? NULL : (sink_element = (gst_object_unref (sink_element), NULL));
 			return result;
 		}
-		if (!gee_collection_contains ((GeeCollection*) self->priv->_active_channels, channel)) {
+		if (!gee_abstract_collection_contains ((GeeAbstractCollection*) self->priv->_active_channels, channel)) {
 			g_static_rec_mutex_lock (&self->priv->__lock_pipeline);
 			{
 				GstElement* _tmp6_;
@@ -480,7 +480,7 @@ GstElement* dvb_player_thread_get_element (DVBPlayerThread* self, DVBChannel* ch
 			{
 				DVBPlayerThreadChannelElements* _tmp9_;
 				_tmp9_ = NULL;
-				c_element = (_tmp9_ = (DVBPlayerThreadChannelElements*) gee_map_get ((GeeMap*) self->priv->elements_map, GUINT_TO_POINTER (channel_sid)), (c_element == NULL) ? NULL : (c_element = (dvb_player_thread_channel_elements_unref (c_element), NULL)), _tmp9_);
+				c_element = (_tmp9_ = (DVBPlayerThreadChannelElements*) gee_abstract_map_get ((GeeAbstractMap*) self->priv->elements_map, GUINT_TO_POINTER (channel_sid)), (c_element == NULL) ? NULL : (c_element = (dvb_player_thread_channel_elements_unref (c_element), NULL)), _tmp9_);
 			}
 			g_static_rec_mutex_unlock (&self->priv->__lock_elements_map);
 			_tmp11_ = NULL;
@@ -509,7 +509,7 @@ GstElement* dvb_player_thread_get_element (DVBPlayerThread* self, DVBChannel* ch
 				(sink_element == NULL) ? NULL : (sink_element = (gst_object_unref (sink_element), NULL));
 				return result;
 			}
-			gee_collection_add ((GeeCollection*) c_element->sinks, bin);
+			gee_abstract_collection_add ((GeeAbstractCollection*) c_element->sinks, bin);
 			create_channel = FALSE;
 			(c_element == NULL) ? NULL : (c_element = (dvb_player_thread_channel_elements_unref (c_element), NULL));
 		}
@@ -523,7 +523,7 @@ GstElement* dvb_player_thread_get_element (DVBPlayerThread* self, DVBChannel* ch
 		celems->sid = channel_sid;
 		_tmp15_ = NULL;
 		celems->sinks = (_tmp15_ = gee_array_list_new (GST_TYPE_ELEMENT, (GBoxedCopyFunc) gst_object_ref, gst_object_unref, g_direct_equal), (celems->sinks == NULL) ? NULL : (celems->sinks = (g_object_unref (celems->sinks), NULL)), _tmp15_);
-		gee_collection_add ((GeeCollection*) celems->sinks, bin);
+		gee_abstract_collection_add ((GeeAbstractCollection*) celems->sinks, bin);
 		_tmp17_ = NULL;
 		_tmp16_ = NULL;
 		celems->tee = (_tmp17_ = (_tmp16_ = tee, (_tmp16_ == NULL) ? NULL : gst_object_ref (_tmp16_)), (celems->tee == NULL) ? NULL : (celems->tee = (gst_object_unref (celems->tee), NULL)), _tmp17_);
@@ -531,10 +531,10 @@ GstElement* dvb_player_thread_get_element (DVBPlayerThread* self, DVBChannel* ch
 		celems->notify_func = notify_func;
 		g_static_rec_mutex_lock (&self->priv->__lock_elements_map);
 		{
-			gee_map_set ((GeeMap*) self->priv->elements_map, GUINT_TO_POINTER (channel_sid), celems);
+			gee_abstract_map_set ((GeeAbstractMap*) self->priv->elements_map, GUINT_TO_POINTER (channel_sid), celems);
 		}
 		g_static_rec_mutex_unlock (&self->priv->__lock_elements_map);
-		gee_collection_add ((GeeCollection*) self->priv->_active_channels, channel);
+		gee_abstract_collection_add ((GeeAbstractCollection*) self->priv->_active_channels, channel);
 		(celems == NULL) ? NULL : (celems = (dvb_player_thread_channel_elements_unref (celems), NULL));
 	}
 	result = bin;
@@ -630,11 +630,11 @@ GstElement* dvb_player_thread_get_sink_bin (DVBPlayerThread* self, guint sid, Gs
 	g_static_rec_mutex_lock (&self->priv->__lock_elements_map);
 	{
 		DVBPlayerThreadChannelElements* celems;
-		celems = (DVBPlayerThreadChannelElements*) gee_map_get ((GeeMap*) self->priv->elements_map, GUINT_TO_POINTER (sid));
+		celems = (DVBPlayerThreadChannelElements*) gee_abstract_map_get ((GeeAbstractMap*) self->priv->elements_map, GUINT_TO_POINTER (sid));
 		if (celems != NULL) {
 			{
 				GeeIterator* _sink_bin_it;
-				_sink_bin_it = gee_iterable_iterator ((GeeIterable*) celems->sinks);
+				_sink_bin_it = gee_abstract_collection_iterator ((GeeAbstractCollection*) celems->sinks);
 				while (TRUE) {
 					GstElement* sink_bin;
 					GstIterator* it;
@@ -689,7 +689,7 @@ gboolean dvb_player_thread_remove_channel (DVBPlayerThread* self, DVBChannel* ch
 	g_return_val_if_fail (channel != NULL, FALSE);
 	g_return_val_if_fail (sink != NULL, FALSE);
 	channel_sid = dvb_channel_get_Sid (channel);
-	if (!gee_collection_contains ((GeeCollection*) self->priv->_active_channels, channel)) {
+	if (!gee_abstract_collection_contains ((GeeAbstractCollection*) self->priv->_active_channels, channel)) {
 		g_critical ("ChannelFactory.vala:282: Could not find channel with SID %u", channel_sid);
 		result = FALSE;
 		return result;
@@ -705,16 +705,16 @@ gboolean dvb_player_thread_remove_channel (DVBPlayerThread* self, DVBChannel* ch
 			g_static_rec_mutex_lock (&self->priv->__lock_elements_map);
 			{
 				DVBPlayerThreadChannelElements* celements;
-				celements = (DVBPlayerThreadChannelElements*) gee_map_get ((GeeMap*) self->priv->elements_map, GUINT_TO_POINTER (channel_sid));
+				celements = (DVBPlayerThreadChannelElements*) gee_abstract_map_get ((GeeAbstractMap*) self->priv->elements_map, GUINT_TO_POINTER (channel_sid));
 				if (gee_collection_get_size ((GeeCollection*) celements->sinks) == 1) {
 					/* this is the last sink
 					 (no one watches this channel anymore)*/
-					gee_map_remove ((GeeMap*) self->priv->elements_map, GUINT_TO_POINTER (channel_sid));
+					gee_abstract_map_remove ((GeeAbstractMap*) self->priv->elements_map, GUINT_TO_POINTER (channel_sid), NULL);
 					stop_channel = TRUE;
 				} else {
 					/* we still have sinks left
 					 (others are still watching this channel)*/
-					gee_collection_remove ((GeeCollection*) celements->sinks, sink);
+					gee_abstract_collection_remove ((GeeAbstractCollection*) celements->sinks, sink);
 					stop_channel = FALSE;
 				}
 				(celements == NULL) ? NULL : (celements = (dvb_player_thread_channel_elements_unref (celements), NULL));
@@ -789,7 +789,7 @@ gboolean dvb_player_thread_remove_channel (DVBPlayerThread* self, DVBChannel* ch
 				gst_element_set_state (self->priv->pipeline, GST_STATE_PAUSED);
 				g_object_set ((GObject*) self->priv->dvbbasebin, "program-numbers", new_programs->str, NULL);
 				gst_element_set_state (self->priv->pipeline, GST_STATE_PLAYING);
-				gee_collection_remove ((GeeCollection*) self->priv->_active_channels, channel);
+				gee_abstract_collection_remove ((GeeAbstractCollection*) self->priv->_active_channels, channel);
 				programs = (g_free (programs), NULL);
 				programs_arr = (_vala_array_free (programs_arr, programs_arr_length1, (GDestroyNotify) g_free), NULL);
 				(new_programs_list == NULL) ? NULL : (new_programs_list = (_g_slist_free_g_free (new_programs_list), NULL));
@@ -803,7 +803,7 @@ gboolean dvb_player_thread_remove_channel (DVBPlayerThread* self, DVBChannel* ch
 		g_static_rec_mutex_lock (&self->priv->__lock_elements_map);
 		{
 			DVBPlayerThreadChannelElements* celements;
-			celements = (DVBPlayerThreadChannelElements*) gee_map_get ((GeeMap*) self->priv->elements_map, GUINT_TO_POINTER (channel_sid));
+			celements = (DVBPlayerThreadChannelElements*) gee_abstract_map_get ((GeeAbstractMap*) self->priv->elements_map, GUINT_TO_POINTER (channel_sid));
 			if (gee_collection_get_size ((GeeCollection*) celements->sinks) == 1) {
 				/* this is the last sink
 				 (no one watches this channel anymore)*/
@@ -812,7 +812,7 @@ gboolean dvb_player_thread_remove_channel (DVBPlayerThread* self, DVBChannel* ch
 				/* we still have sinks left
 				 (others are still watching this channel)*/
 				dvb_player_thread_remove_sink_bin (self, channel_sid, sink);
-				gee_collection_remove ((GeeCollection*) celements->sinks, sink);
+				gee_abstract_collection_remove ((GeeAbstractCollection*) celements->sinks, sink);
 			}
 			(celements == NULL) ? NULL : (celements = (dvb_player_thread_channel_elements_unref (celements), NULL));
 		}
@@ -860,7 +860,7 @@ static void dvb_player_thread_real_destroy (DVBPlayerThread* self, gboolean forc
 					GeeIterator* _celems_it;
 					_tmp0_ = NULL;
 					_tmp1_ = NULL;
-					_celems_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = gee_map_get_values ((GeeMap*) self->priv->elements_map))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (g_object_unref (_tmp0_), NULL)), _tmp1_);
+					_celems_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = gee_abstract_map_get_values ((GeeAbstractMap*) self->priv->elements_map))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (g_object_unref (_tmp0_), NULL)), _tmp1_);
 					while (TRUE) {
 						DVBPlayerThreadChannelElements* celems;
 						if (!gee_iterator_next (_celems_it)) {
@@ -897,10 +897,10 @@ static void dvb_player_thread_real_destroy (DVBPlayerThread* self, gboolean forc
 		g_static_rec_mutex_unlock (&self->priv->__lock_pipeline);
 		g_static_rec_mutex_lock (&self->priv->__lock_elements_map);
 		{
-			gee_map_clear ((GeeMap*) self->priv->elements_map);
+			gee_abstract_map_clear ((GeeAbstractMap*) self->priv->elements_map);
 		}
 		g_static_rec_mutex_unlock (&self->priv->__lock_elements_map);
-		gee_collection_clear ((GeeCollection*) self->priv->_active_channels);
+		gee_abstract_collection_clear ((GeeAbstractCollection*) self->priv->_active_channels);
 		self->priv->destroyed = TRUE;
 	}
 	g_static_rec_mutex_unlock (&self->priv->__lock_destroyed);
@@ -955,7 +955,7 @@ static void dvb_player_thread_on_dvbbasebin_pad_added (DVBPlayerThread* self, Gs
 	g_debug ("ChannelFactory.vala:430: SID is '%u'", sid);
 	g_static_rec_mutex_lock (&self->priv->__lock_elements_map);
 	{
-		if (gee_map_contains ((GeeMap*) self->priv->elements_map, GUINT_TO_POINTER (sid))) {
+		if (gee_abstract_map_contains ((GeeAbstractMap*) self->priv->elements_map, GUINT_TO_POINTER (sid))) {
 			GstElement* _tmp1_;
 			DVBPlayerThreadChannelElements* _tmp0_;
 			GstElement* _tmp2_;
@@ -967,7 +967,7 @@ static void dvb_player_thread_on_dvbbasebin_pad_added (DVBPlayerThread* self, Gs
 			_tmp1_ = NULL;
 			_tmp0_ = NULL;
 			_tmp2_ = NULL;
-			sink = (_tmp2_ = (_tmp1_ = (_tmp0_ = (DVBPlayerThreadChannelElements*) gee_map_get ((GeeMap*) self->priv->elements_map, GUINT_TO_POINTER (sid)))->tee, (_tmp1_ == NULL) ? NULL : gst_object_ref (_tmp1_)), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (dvb_player_thread_channel_elements_unref (_tmp0_), NULL)), _tmp2_);
+			sink = (_tmp2_ = (_tmp1_ = (_tmp0_ = (DVBPlayerThreadChannelElements*) gee_abstract_map_get ((GeeAbstractMap*) self->priv->elements_map, GUINT_TO_POINTER (sid)))->tee, (_tmp1_ == NULL) ? NULL : gst_object_ref (_tmp1_)), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (dvb_player_thread_channel_elements_unref (_tmp0_), NULL)), _tmp2_);
 			if (sink == NULL) {
 				g_critical ("ChannelFactory.vala:436: Could not find sink for SID %u", sid);
 				(sink == NULL) ? NULL : (sink = (gst_object_unref (sink), NULL));
@@ -1089,7 +1089,7 @@ gboolean dvb_player_thread_get_forced (DVBPlayerThread* self) {
 			GeeIterator* _celem_it;
 			_tmp0_ = NULL;
 			_tmp1_ = NULL;
-			_celem_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = gee_map_get_values ((GeeMap*) self->priv->elements_map))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (g_object_unref (_tmp0_), NULL)), _tmp1_);
+			_celem_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = gee_abstract_map_get_values ((GeeAbstractMap*) self->priv->elements_map))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (g_object_unref (_tmp0_), NULL)), _tmp1_);
 			while (TRUE) {
 				DVBPlayerThreadChannelElements* celem;
 				if (!gee_iterator_next (_celem_it)) {
@@ -1414,7 +1414,7 @@ void dvb_channel_factory_destroy (DVBChannelFactory* self) {
 	{
 		{
 			GeeIterator* _active_player_it;
-			_active_player_it = gee_iterable_iterator ((GeeIterable*) self->priv->active_players);
+			_active_player_it = gee_abstract_collection_iterator ((GeeAbstractCollection*) self->priv->active_players);
 			while (TRUE) {
 				DVBPlayerThread* active_player;
 				if (!gee_iterator_next (_active_player_it)) {
@@ -1426,7 +1426,7 @@ void dvb_channel_factory_destroy (DVBChannelFactory* self) {
 			}
 			(_active_player_it == NULL) ? NULL : (_active_player_it = (g_object_unref (_active_player_it), NULL));
 		}
-		gee_collection_clear ((GeeCollection*) self->priv->active_players);
+		gee_abstract_collection_clear ((GeeAbstractCollection*) self->priv->active_players);
 	}
 	g_static_rec_mutex_unlock (&self->priv->__lock_active_players);
 }
@@ -1474,7 +1474,7 @@ DVBPlayerThread* dvb_channel_factory_watch_channel (DVBChannelFactory* self, DVB
 	{
 		{
 			GeeIterator* _active_player_it;
-			_active_player_it = gee_iterable_iterator ((GeeIterable*) self->priv->active_players);
+			_active_player_it = gee_abstract_collection_iterator ((GeeAbstractCollection*) self->priv->active_players);
 			while (TRUE) {
 				DVBPlayerThread* active_player;
 				if (!gee_iterator_next (_active_player_it)) {
@@ -1483,7 +1483,7 @@ DVBPlayerThread* dvb_channel_factory_watch_channel (DVBChannelFactory* self, DVB
 				active_player = (DVBPlayerThread*) gee_iterator_get (_active_player_it);
 				{
 					GeeIterator* _other_channel_it;
-					_other_channel_it = gee_iterable_iterator ((GeeIterable*) dvb_player_thread_get_active_channels (active_player));
+					_other_channel_it = gee_abstract_collection_iterator ((GeeAbstractCollection*) dvb_player_thread_get_active_channels (active_player));
 					while (TRUE) {
 						DVBChannel* other_channel;
 						if (!gee_iterator_next (_other_channel_it)) {
@@ -1539,7 +1539,7 @@ DVBPlayerThread* dvb_channel_factory_watch_channel (DVBChannelFactory* self, DVB
 			{
 				{
 					GeeIterator* _active_player_it;
-					_active_player_it = gee_iterable_iterator ((GeeIterable*) self->priv->active_players);
+					_active_player_it = gee_abstract_collection_iterator ((GeeAbstractCollection*) self->priv->active_players);
 					while (TRUE) {
 						DVBPlayerThread* active_player;
 						if (!gee_iterator_next (_active_player_it)) {
@@ -1581,7 +1581,7 @@ DVBPlayerThread* dvb_channel_factory_watch_channel (DVBChannelFactory* self, DVB
 	(_tmp9_ == NULL) ? NULL : (_tmp9_ = (gst_object_unref (_tmp9_), NULL));
 	g_static_rec_mutex_lock (&self->priv->__lock_active_players);
 	{
-		gee_collection_add ((GeeCollection*) self->priv->active_players, player);
+		gee_abstract_collection_add ((GeeAbstractCollection*) self->priv->active_players, player);
 	}
 	g_static_rec_mutex_unlock (&self->priv->__lock_active_players);
 	result = player;
@@ -1611,14 +1611,14 @@ gboolean dvb_channel_factory_stop_channel (DVBChannelFactory* self, DVBChannel*
 		gboolean _tmp2_;
 		{
 			GeeIterator* _active_player_it;
-			_active_player_it = gee_iterable_iterator ((GeeIterable*) self->priv->active_players);
+			_active_player_it = gee_abstract_collection_iterator ((GeeAbstractCollection*) self->priv->active_players);
 			while (TRUE) {
 				DVBPlayerThread* active_player;
 				if (!gee_iterator_next (_active_player_it)) {
 					break;
 				}
 				active_player = (DVBPlayerThread*) gee_iterator_get (_active_player_it);
-				if (gee_collection_contains ((GeeCollection*) dvb_player_thread_get_active_channels (active_player), channel)) {
+				if (gee_abstract_collection_contains ((GeeAbstractCollection*) dvb_player_thread_get_active_channels (active_player), channel)) {
 					DVBPlayerThread* _tmp1_;
 					DVBPlayerThread* _tmp0_;
 					success = dvb_player_thread_remove_channel (active_player, channel, sink);
@@ -1639,7 +1639,7 @@ gboolean dvb_channel_factory_stop_channel (DVBChannelFactory* self, DVBChannel*
 			_tmp2_ = FALSE;
 		}
 		if (_tmp2_) {
-			gee_collection_remove ((GeeCollection*) self->priv->active_players, player);
+			gee_abstract_collection_remove ((GeeAbstractCollection*) self->priv->active_players, player);
 		}
 		if (gee_collection_get_size ((GeeCollection*) self->priv->active_players) == 0) {
 			DVBEPGScanner* _tmp3_;
