@@ -17,19 +17,106 @@
  * along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <src/ChannelListReader.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <gio/gio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <gee.h>
-#include "src/Utils.h"
-#include "src/Channel.h"
-#include "src/Terrestrial/TerrestrialChannel.h"
-#include "src/MpegTsEnums.h"
-#include "src/Satellite/SatelliteChannel.h"
-#include "src/Cable/CableChannel.h"
 
 
+#define DVB_TYPE_CHANNEL_LIST_READER (dvb_channel_list_reader_get_type ())
+#define DVB_CHANNEL_LIST_READER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_CHANNEL_LIST_READER, DVBChannelListReader))
+#define DVB_CHANNEL_LIST_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_CHANNEL_LIST_READER, DVBChannelListReaderClass))
+#define DVB_IS_CHANNEL_LIST_READER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_CHANNEL_LIST_READER))
+#define DVB_IS_CHANNEL_LIST_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_CHANNEL_LIST_READER))
+#define DVB_CHANNEL_LIST_READER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_CHANNEL_LIST_READER, DVBChannelListReaderClass))
 
+typedef struct _DVBChannelListReader DVBChannelListReader;
+typedef struct _DVBChannelListReaderClass DVBChannelListReaderClass;
+typedef struct _DVBChannelListReaderPrivate DVBChannelListReaderPrivate;
+
+#define DVB_TYPE_ADAPTER_TYPE (dvb_adapter_type_get_type ())
+
+#define DVB_TYPE_CHANNEL_LIST (dvb_channel_list_get_type ())
+#define DVB_CHANNEL_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_CHANNEL_LIST, DVBChannelList))
+#define DVB_CHANNEL_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_CHANNEL_LIST, DVBChannelListClass))
+#define DVB_IS_CHANNEL_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_CHANNEL_LIST))
+#define DVB_IS_CHANNEL_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_CHANNEL_LIST))
+#define DVB_CHANNEL_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_CHANNEL_LIST, DVBChannelListClass))
+
+typedef struct _DVBChannelList DVBChannelList;
+typedef struct _DVBChannelListClass DVBChannelListClass;
+
+#define DVB_TYPE_CHANNEL (dvb_channel_get_type ())
+#define DVB_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_CHANNEL, DVBChannel))
+#define DVB_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_CHANNEL, DVBChannelClass))
+#define DVB_IS_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_CHANNEL))
+#define DVB_IS_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_CHANNEL))
+#define DVB_CHANNEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_CHANNEL, DVBChannelClass))
+
+typedef struct _DVBChannel DVBChannel;
+typedef struct _DVBChannelClass DVBChannelClass;
+
+#define DVB_TYPE_TERRESTRIAL_CHANNEL (dvb_terrestrial_channel_get_type ())
+#define DVB_TERRESTRIAL_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_TERRESTRIAL_CHANNEL, DVBTerrestrialChannel))
+#define DVB_TERRESTRIAL_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_TERRESTRIAL_CHANNEL, DVBTerrestrialChannelClass))
+#define DVB_IS_TERRESTRIAL_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_TERRESTRIAL_CHANNEL))
+#define DVB_IS_TERRESTRIAL_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_TERRESTRIAL_CHANNEL))
+#define DVB_TERRESTRIAL_CHANNEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_TERRESTRIAL_CHANNEL, DVBTerrestrialChannelClass))
+
+typedef struct _DVBTerrestrialChannel DVBTerrestrialChannel;
+typedef struct _DVBTerrestrialChannelClass DVBTerrestrialChannelClass;
+
+#define DVB_TYPE_SATELLITE_CHANNEL (dvb_satellite_channel_get_type ())
+#define DVB_SATELLITE_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_SATELLITE_CHANNEL, DVBSatelliteChannel))
+#define DVB_SATELLITE_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_SATELLITE_CHANNEL, DVBSatelliteChannelClass))
+#define DVB_IS_SATELLITE_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_SATELLITE_CHANNEL))
+#define DVB_IS_SATELLITE_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_SATELLITE_CHANNEL))
+#define DVB_SATELLITE_CHANNEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_SATELLITE_CHANNEL, DVBSatelliteChannelClass))
+
+typedef struct _DVBSatelliteChannel DVBSatelliteChannel;
+typedef struct _DVBSatelliteChannelClass DVBSatelliteChannelClass;
+
+#define DVB_TYPE_CABLE_CHANNEL (dvb_cable_channel_get_type ())
+#define DVB_CABLE_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_CABLE_CHANNEL, DVBCableChannel))
+#define DVB_CABLE_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_CABLE_CHANNEL, DVBCableChannelClass))
+#define DVB_IS_CABLE_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_CABLE_CHANNEL))
+#define DVB_IS_CABLE_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_CABLE_CHANNEL))
+#define DVB_CABLE_CHANNEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_CABLE_CHANNEL, DVBCableChannelClass))
+
+typedef struct _DVBCableChannel DVBCableChannel;
+typedef struct _DVBCableChannelClass DVBCableChannelClass;
+
+#define DVB_TYPE_DVB_SRC_INVERSION (dvb_dvb_src_inversion_get_type ())
+
+#define DVB_TYPE_DVB_SRC_BANDWIDTH (dvb_dvb_src_bandwidth_get_type ())
+
+#define DVB_TYPE_DVB_SRC_CODE_RATE (dvb_dvb_src_code_rate_get_type ())
+
+#define DVB_TYPE_DVB_SRC_MODULATION (dvb_dvb_src_modulation_get_type ())
+
+#define DVB_TYPE_DVB_SRC_TRANSMISSION_MODE (dvb_dvb_src_transmission_mode_get_type ())
+
+#define DVB_TYPE_DVB_SRC_GUARD (dvb_dvb_src_guard_get_type ())
+
+#define DVB_TYPE_DVB_SRC_HIERARCHY (dvb_dvb_src_hierarchy_get_type ())
+
+struct _DVBChannelListReader {
+	GObject parent_instance;
+	DVBChannelListReaderPrivate * priv;
+};
+
+struct _DVBChannelListReaderClass {
+	GObjectClass parent_class;
+};
+
+typedef enum  {
+	DVB_ADAPTER_TYPE_UNKNOWN,
+	DVB_ADAPTER_TYPE_DVB_T,
+	DVB_ADAPTER_TYPE_DVB_S,
+	DVB_ADAPTER_TYPE_DVB_C
+} DVBAdapterType;
 
 struct _DVBChannelListReaderPrivate {
 	GFile* _ChannelFile;
@@ -37,6 +124,69 @@ struct _DVBChannelListReaderPrivate {
 	guint _GroupId;
 };
 
+typedef enum  {
+	DVB_DVB_SRC_INVERSION_INVERSION_OFF,
+	DVB_DVB_SRC_INVERSION_INVERSION_ON,
+	DVB_DVB_SRC_INVERSION_INVERSION_AUTO
+} DVBDvbSrcInversion;
+
+typedef enum  {
+	DVB_DVB_SRC_BANDWIDTH_BANDWIDTH_8_MHZ,
+	DVB_DVB_SRC_BANDWIDTH_BANDWIDTH_7_MHZ,
+	DVB_DVB_SRC_BANDWIDTH_BANDWIDTH_6_MHZ,
+	DVB_DVB_SRC_BANDWIDTH_BANDWIDTH_AUTO
+} DVBDvbSrcBandwidth;
+
+typedef enum  {
+	DVB_DVB_SRC_CODE_RATE_FEC_NONE,
+	DVB_DVB_SRC_CODE_RATE_FEC_1_2,
+	DVB_DVB_SRC_CODE_RATE_FEC_2_3,
+	DVB_DVB_SRC_CODE_RATE_FEC_3_4,
+	DVB_DVB_SRC_CODE_RATE_FEC_4_5,
+	DVB_DVB_SRC_CODE_RATE_FEC_5_6,
+	DVB_DVB_SRC_CODE_RATE_FEC_6_7,
+	DVB_DVB_SRC_CODE_RATE_FEC_7_8,
+	DVB_DVB_SRC_CODE_RATE_FEC_8_9,
+	DVB_DVB_SRC_CODE_RATE_FEC_AUTO
+} DVBDvbSrcCodeRate;
+
+typedef enum  {
+	DVB_DVB_SRC_MODULATION_QPSK,
+	DVB_DVB_SRC_MODULATION_QAM_16,
+	DVB_DVB_SRC_MODULATION_QAM_32,
+	DVB_DVB_SRC_MODULATION_QAM_64,
+	DVB_DVB_SRC_MODULATION_QAM_128,
+	DVB_DVB_SRC_MODULATION_QAM_256,
+	DVB_DVB_SRC_MODULATION_QAM_AUTO
+} DVBDvbSrcModulation;
+
+typedef enum  {
+	DVB_DVB_SRC_TRANSMISSION_MODE_TRANSMISSION_MODE_2K,
+	DVB_DVB_SRC_TRANSMISSION_MODE_TRANSMISSION_MODE_8K,
+	DVB_DVB_SRC_TRANSMISSION_MODE_TRANSMISSION_MODE_AUTO
+} DVBDvbSrcTransmissionMode;
+
+typedef enum  {
+	DVB_DVB_SRC_GUARD_GUARD_INTERVAL_1_32,
+	DVB_DVB_SRC_GUARD_GUARD_INTERVAL_1_16,
+	DVB_DVB_SRC_GUARD_GUARD_INTERVAL_1_8,
+	DVB_DVB_SRC_GUARD_GUARD_INTERVAL_1_4,
+	DVB_DVB_SRC_GUARD_GUARD_INTERVAL_AUTO
+} DVBDvbSrcGuard;
+
+typedef enum  {
+	DVB_DVB_SRC_HIERARCHY_HIERARCHY_NONE,
+	DVB_DVB_SRC_HIERARCHY_HIERARCHY_1,
+	DVB_DVB_SRC_HIERARCHY_HIERARCHY_2,
+	DVB_DVB_SRC_HIERARCHY_HIERARCHY_4,
+	DVB_DVB_SRC_HIERARCHY_HIERARCHY_AUTO
+} DVBDvbSrcHierarchy;
+
+
+static gpointer dvb_channel_list_reader_parent_class = NULL;
+
+GType dvb_channel_list_reader_get_type (void);
+GType dvb_adapter_type_get_type (void);
 #define DVB_CHANNEL_LIST_READER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DVB_TYPE_CHANNEL_LIST_READER, DVBChannelListReaderPrivate))
 enum  {
 	DVB_CHANNEL_LIST_READER_DUMMY_PROPERTY,
@@ -44,16 +194,70 @@ enum  {
 	DVB_CHANNEL_LIST_READER_TYPE,
 	DVB_CHANNEL_LIST_READER_GROUP_ID
 };
-static DVBChannel* dvb_channel_list_reader_parse_line (DVBChannelListReader* self, const char* line);
-static DVBTerrestrialChannel* dvb_channel_list_reader_parse_terrestrial_channel (DVBChannelListReader* self, const char* line);
-static DVBSatelliteChannel* dvb_channel_list_reader_parse_satellite_channel (DVBChannelListReader* self, const char* line);
-static DVBCableChannel* dvb_channel_list_reader_parse_cable_channel (DVBChannelListReader* self, const char* line);
-static gboolean dvb_channel_list_reader_get_value_with_prefix (GType enumtype, const char* name, const char* prefix, gint* val);
 static void dvb_channel_list_reader_set_ChannelFile (DVBChannelListReader* self, GFile* value);
 static void dvb_channel_list_reader_set_Type (DVBChannelListReader* self, DVBAdapterType value);
 static void dvb_channel_list_reader_set_GroupId (DVBChannelListReader* self, guint value);
-static gpointer dvb_channel_list_reader_parent_class = NULL;
+DVBChannelListReader* dvb_channel_list_reader_new (GFile* file, DVBAdapterType type, guint group_id);
+DVBChannelListReader* dvb_channel_list_reader_construct (GType object_type, GFile* file, DVBAdapterType type, guint group_id);
+char* dvb_utils_read_file_contents (GFile* file, GError** error);
+GFile* dvb_channel_list_reader_get_ChannelFile (DVBChannelListReader* self);
+DVBChannelList* dvb_channel_list_new (GFile* channels);
+DVBChannelList* dvb_channel_list_construct (GType object_type, GFile* channels);
+GType dvb_channel_list_get_type (void);
+GType dvb_channel_get_type (void);
+static DVBChannel* dvb_channel_list_reader_parse_line (DVBChannelListReader* self, const char* line);
+void dvb_channel_list_add (DVBChannelList* self, DVBChannel* channel);
+DVBChannelList* dvb_channel_list_reader_read (DVBChannelListReader* self, GError** error);
+DVBAdapterType dvb_channel_list_reader_get_Type (DVBChannelListReader* self);
+GType dvb_terrestrial_channel_get_type (void);
+static DVBTerrestrialChannel* dvb_channel_list_reader_parse_terrestrial_channel (DVBChannelListReader* self, const char* line);
+GType dvb_satellite_channel_get_type (void);
+static DVBSatelliteChannel* dvb_channel_list_reader_parse_satellite_channel (DVBChannelListReader* self, const char* line);
+GType dvb_cable_channel_get_type (void);
+static DVBCableChannel* dvb_channel_list_reader_parse_cable_channel (DVBChannelListReader* self, const char* line);
+gboolean dvb_channel_is_valid (DVBChannel* self);
+char* dvb_channel_to_string (DVBChannel* self);
+DVBTerrestrialChannel* dvb_terrestrial_channel_new (void);
+DVBTerrestrialChannel* dvb_terrestrial_channel_construct (GType object_type);
+guint dvb_channel_list_reader_get_GroupId (DVBChannelListReader* self);
+void dvb_channel_set_GroupId (DVBChannel* self, guint value);
+void dvb_channel_set_Name (DVBChannel* self, const char* value);
+void dvb_channel_set_Frequency (DVBChannel* self, guint value);
+static gboolean dvb_channel_list_reader_get_value_with_prefix (GType enumtype, const char* name, const char* prefix, gint* val);
+GType dvb_dvb_src_inversion_get_type (void);
+void dvb_terrestrial_channel_set_Inversion (DVBTerrestrialChannel* self, DVBDvbSrcInversion value);
+GType dvb_dvb_src_bandwidth_get_type (void);
+void dvb_terrestrial_channel_set_Bandwidth (DVBTerrestrialChannel* self, DVBDvbSrcBandwidth value);
+GType dvb_dvb_src_code_rate_get_type (void);
+void dvb_terrestrial_channel_set_CodeRateHP (DVBTerrestrialChannel* self, DVBDvbSrcCodeRate value);
+void dvb_terrestrial_channel_set_CodeRateLP (DVBTerrestrialChannel* self, DVBDvbSrcCodeRate value);
+GType dvb_dvb_src_modulation_get_type (void);
+void dvb_terrestrial_channel_set_Constellation (DVBTerrestrialChannel* self, DVBDvbSrcModulation value);
+GType dvb_dvb_src_transmission_mode_get_type (void);
+void dvb_terrestrial_channel_set_TransmissionMode (DVBTerrestrialChannel* self, DVBDvbSrcTransmissionMode value);
+GType dvb_dvb_src_guard_get_type (void);
+void dvb_terrestrial_channel_set_GuardInterval (DVBTerrestrialChannel* self, DVBDvbSrcGuard value);
+GType dvb_dvb_src_hierarchy_get_type (void);
+void dvb_terrestrial_channel_set_Hierarchy (DVBTerrestrialChannel* self, DVBDvbSrcHierarchy value);
+void dvb_channel_set_VideoPID (DVBChannel* self, guint value);
+GeeList* dvb_channel_get_AudioPIDs (DVBChannel* self);
+void dvb_channel_set_Sid (DVBChannel* self, guint value);
+DVBSatelliteChannel* dvb_satellite_channel_new (void);
+DVBSatelliteChannel* dvb_satellite_channel_construct (GType object_type);
+void dvb_satellite_channel_set_Polarization (DVBSatelliteChannel* self, const char* value);
+void dvb_satellite_channel_set_DiseqcSource (DVBSatelliteChannel* self, gint value);
+void dvb_satellite_channel_set_SymbolRate (DVBSatelliteChannel* self, guint value);
+DVBCableChannel* dvb_cable_channel_new (void);
+DVBCableChannel* dvb_cable_channel_construct (GType object_type);
+void dvb_cable_channel_set_Inversion (DVBCableChannel* self, DVBDvbSrcInversion value);
+void dvb_cable_channel_set_SymbolRate (DVBCableChannel* self, guint value);
+void dvb_cable_channel_set_CodeRate (DVBCableChannel* self, DVBDvbSrcCodeRate value);
+void dvb_cable_channel_set_Modulation (DVBCableChannel* self, DVBDvbSrcModulation value);
+gboolean dvb_utils_get_value_by_name_from_enum (GType enumtype, const char* name, gint* evalue);
 static void dvb_channel_list_reader_finalize (GObject* obj);
+static void dvb_channel_list_reader_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
+static void dvb_channel_list_reader_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
+static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static gint _vala_array_length (gpointer array);
 
@@ -94,36 +298,36 @@ DVBChannelListReader* dvb_channel_list_reader_new (GFile* file, DVBAdapterType t
 
 
 DVBChannelList* dvb_channel_list_reader_read (DVBChannelListReader* self, GError** error) {
-	GError * inner_error;
+	DVBChannelList* result;
+	GError * _inner_error_;
 	char* contents;
 	DVBChannelList* channels;
-	DVBChannelList* _tmp3;
 	g_return_val_if_fail (self != NULL, NULL);
-	inner_error = NULL;
-	contents = dvb_utils_read_file_contents (self->priv->_ChannelFile, &inner_error);
-	if (inner_error != NULL) {
-		g_propagate_error (error, inner_error);
+	_inner_error_ = NULL;
+	contents = dvb_utils_read_file_contents (self->priv->_ChannelFile, &_inner_error_);
+	if (_inner_error_ != NULL) {
+		g_propagate_error (error, _inner_error_);
 		return NULL;
 	}
 	if (contents == NULL) {
-		DVBChannelList* _tmp0;
-		_tmp0 = NULL;
-		return (_tmp0 = NULL, contents = (g_free (contents), NULL), _tmp0);
+		result = NULL;
+		contents = (g_free (contents), NULL);
+		return result;
 	}
 	channels = dvb_channel_list_new (self->priv->_ChannelFile);
 	{
-		char** _tmp1;
+		char** _tmp0_;
 		char** line_collection;
 		int line_collection_length1;
 		int line_it;
-		_tmp1 = NULL;
-		line_collection = _tmp1 = g_strsplit (contents, "\n", 0);
-		line_collection_length1 = _vala_array_length (_tmp1);
-		for (line_it = 0; line_it < _vala_array_length (_tmp1); line_it = line_it + 1) {
-			const char* _tmp2;
+		_tmp0_ = NULL;
+		line_collection = _tmp0_ = g_strsplit (contents, "\n", 0);
+		line_collection_length1 = _vala_array_length (_tmp0_);
+		for (line_it = 0; line_it < _vala_array_length (_tmp0_); line_it = line_it + 1) {
+			const char* _tmp1_;
 			char* line;
-			_tmp2 = NULL;
-			line = (_tmp2 = line_collection[line_it], (_tmp2 == NULL) ? NULL : g_strdup (_tmp2));
+			_tmp1_ = NULL;
+			line = (_tmp1_ = line_collection[line_it], (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
 			{
 				if (strlen (line) > 0) {
 					DVBChannel* c;
@@ -140,37 +344,39 @@ DVBChannelList* dvb_channel_list_reader_read (DVBChannelListReader* self, GError
 		}
 		line_collection = (_vala_array_free (line_collection, line_collection_length1, (GDestroyNotify) g_free), NULL);
 	}
-	_tmp3 = NULL;
-	return (_tmp3 = channels, contents = (g_free (contents), NULL), _tmp3);
+	result = channels;
+	contents = (g_free (contents), NULL);
+	return result;
 }
 
 
 static DVBChannel* dvb_channel_list_reader_parse_line (DVBChannelListReader* self, const char* line) {
+	DVBChannel* result;
 	DVBChannel* c;
-	gboolean _tmp3;
+	gboolean _tmp3_;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (line != NULL, NULL);
 	c = NULL;
 	switch (self->priv->_Type) {
 		case DVB_ADAPTER_TYPE_DVB_T:
 		{
-			DVBChannel* _tmp0;
-			_tmp0 = NULL;
-			c = (_tmp0 = (DVBChannel*) dvb_channel_list_reader_parse_terrestrial_channel (self, line), (c == NULL) ? NULL : (c = (g_object_unref (c), NULL)), _tmp0);
+			DVBChannel* _tmp0_;
+			_tmp0_ = NULL;
+			c = (_tmp0_ = (DVBChannel*) dvb_channel_list_reader_parse_terrestrial_channel (self, line), (c == NULL) ? NULL : (c = (g_object_unref (c), NULL)), _tmp0_);
 			break;
 		}
 		case DVB_ADAPTER_TYPE_DVB_S:
 		{
-			DVBChannel* _tmp1;
-			_tmp1 = NULL;
-			c = (_tmp1 = (DVBChannel*) dvb_channel_list_reader_parse_satellite_channel (self, line), (c == NULL) ? NULL : (c = (g_object_unref (c), NULL)), _tmp1);
+			DVBChannel* _tmp1_;
+			_tmp1_ = NULL;
+			c = (_tmp1_ = (DVBChannel*) dvb_channel_list_reader_parse_satellite_channel (self, line), (c == NULL) ? NULL : (c = (g_object_unref (c), NULL)), _tmp1_);
 			break;
 		}
 		case DVB_ADAPTER_TYPE_DVB_C:
 		{
-			DVBChannel* _tmp2;
-			_tmp2 = NULL;
-			c = (_tmp2 = (DVBChannel*) dvb_channel_list_reader_parse_cable_channel (self, line), (c == NULL) ? NULL : (c = (g_object_unref (c), NULL)), _tmp2);
+			DVBChannel* _tmp2_;
+			_tmp2_ = NULL;
+			c = (_tmp2_ = (DVBChannel*) dvb_channel_list_reader_parse_cable_channel (self, line), (c == NULL) ? NULL : (c = (g_object_unref (c), NULL)), _tmp2_);
 			break;
 		}
 		default:
@@ -179,34 +385,37 @@ static DVBChannel* dvb_channel_list_reader_parse_line (DVBChannelListReader* sel
 			break;
 		}
 	}
-	_tmp3 = FALSE;
+	_tmp3_ = FALSE;
 	if (c != NULL) {
-		_tmp3 = dvb_channel_is_valid (c);
+		_tmp3_ = dvb_channel_is_valid (c);
 	} else {
-		_tmp3 = FALSE;
+		_tmp3_ = FALSE;
 	}
-	if (_tmp3) {
-		return c;
+	if (_tmp3_) {
+		result = c;
+		return result;
 	} else {
-		char* _tmp5;
-		const char* _tmp8;
+		char* _tmp4_;
+		const char* _tmp7_;
 		char* val;
-		DVBChannel* _tmp9;
-		_tmp5 = NULL;
+		_tmp4_ = NULL;
 		if (c == NULL) {
-			char* _tmp6;
-			_tmp6 = NULL;
-			_tmp5 = (_tmp6 = g_strdup ("(null)"), _tmp5 = (g_free (_tmp5), NULL), _tmp6);
+			char* _tmp5_;
+			_tmp5_ = NULL;
+			_tmp4_ = (_tmp5_ = g_strdup ("(null)"), _tmp4_ = (g_free (_tmp4_), NULL), _tmp5_);
 		} else {
-			char* _tmp7;
-			_tmp7 = NULL;
-			_tmp5 = (_tmp7 = dvb_channel_to_string (c), _tmp5 = (g_free (_tmp5), NULL), _tmp7);
+			char* _tmp6_;
+			_tmp6_ = NULL;
+			_tmp4_ = (_tmp6_ = dvb_channel_to_string (c), _tmp4_ = (g_free (_tmp4_), NULL), _tmp6_);
 		}
-		_tmp8 = NULL;
-		val = (_tmp8 = _tmp5, (_tmp8 == NULL) ? NULL : g_strdup (_tmp8));
+		_tmp7_ = NULL;
+		val = (_tmp7_ = _tmp4_, (_tmp7_ == NULL) ? NULL : g_strdup (_tmp7_));
 		g_warning ("ChannelListReader.vala:79: Channel is not valid: %s", val);
-		_tmp9 = NULL;
-		return (_tmp9 = NULL, _tmp5 = (g_free (_tmp5), NULL), val = (g_free (val), NULL), (c == NULL) ? NULL : (c = (g_object_unref (c), NULL)), _tmp9);
+		result = NULL;
+		_tmp4_ = (g_free (_tmp4_), NULL);
+		val = (g_free (val), NULL);
+		(c == NULL) ? NULL : (c = (g_object_unref (c), NULL));
+		return result;
 	}
 	(c == NULL) ? NULL : (c = (g_object_unref (c), NULL));
 }
@@ -220,30 +429,34 @@ static DVBChannel* dvb_channel_list_reader_parse_line (DVBChannelListReader* sel
          * Das Erste:212500000:INVERSION_AUTO:BANDWIDTH_7_MHZ:FEC_3_4:FEC_1_2:QAM_16:TRANSMISSION_MODE_8K:GUARD_INTERVAL_1_4:HIERARCHY_NONE:513:514:32
          */
 static DVBTerrestrialChannel* dvb_channel_list_reader_parse_terrestrial_channel (DVBChannelListReader* self, const char* line) {
+	DVBTerrestrialChannel* result;
 	DVBTerrestrialChannel* channel;
-	char** _tmp1;
+	char** _tmp1_;
 	gint fields_size;
 	gint fields_length1;
-	char** _tmp0;
+	char** _tmp0_;
 	char** fields;
 	gint i;
 	char* val;
 	gboolean failed;
-	char* _tmp3;
-	const char* _tmp2;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (line != NULL, NULL);
 	channel = dvb_terrestrial_channel_new ();
 	dvb_channel_set_GroupId ((DVBChannel*) channel, self->priv->_GroupId);
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	fields = (_tmp1 = _tmp0 = g_strsplit (line, ":", 0), fields_length1 = _vala_array_length (_tmp0), fields_size = fields_length1, _tmp1);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	fields = (_tmp1_ = _tmp0_ = g_strsplit (line, ":", 0), fields_length1 = _vala_array_length (_tmp0_), fields_size = fields_length1, _tmp1_);
 	i = 0;
 	val = NULL;
 	failed = FALSE;
-	_tmp3 = NULL;
-	_tmp2 = NULL;
-	while ((val = (_tmp3 = (_tmp2 = fields[i], (_tmp2 == NULL) ? NULL : g_strdup (_tmp2)), val = (g_free (val), NULL), _tmp3)) != NULL) {
+	while (TRUE) {
+		char* _tmp3_;
+		const char* _tmp2_;
+		_tmp3_ = NULL;
+		_tmp2_ = NULL;
+		if (!((val = (_tmp3_ = (_tmp2_ = fields[i], (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_)), val = (g_free (val), NULL), _tmp3_)) != NULL)) {
+			break;
+		}
 		if (i == 0) {
 			if (g_utf8_validate (val, -1, NULL)) {
 				dvb_channel_set_Name ((DVBChannel*) channel, val);
@@ -359,13 +572,16 @@ static DVBTerrestrialChannel* dvb_channel_list_reader_parse_terrestrial_channel
 		i++;
 	}
 	if (failed) {
-		DVBTerrestrialChannel* _tmp4;
-		_tmp4 = NULL;
-		return (_tmp4 = NULL, (channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL)), fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), val = (g_free (val), NULL), _tmp4);
+		result = NULL;
+		(channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL));
+		fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL);
+		val = (g_free (val), NULL);
+		return result;
 	} else {
-		DVBTerrestrialChannel* _tmp5;
-		_tmp5 = NULL;
-		return (_tmp5 = channel, fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), val = (g_free (val), NULL), _tmp5);
+		result = channel;
+		fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL);
+		val = (g_free (val), NULL);
+		return result;
 	}
 	(channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL));
 	fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL);
@@ -379,29 +595,32 @@ static DVBTerrestrialChannel* dvb_channel_list_reader_parse_terrestrial_channel
          * Das Erste:11836:h:0:27500:101:102:28106
          */
 static DVBSatelliteChannel* dvb_channel_list_reader_parse_satellite_channel (DVBChannelListReader* self, const char* line) {
+	DVBSatelliteChannel* result;
 	DVBSatelliteChannel* channel;
-	char** _tmp1;
+	char** _tmp1_;
 	gint fields_size;
 	gint fields_length1;
-	char** _tmp0;
+	char** _tmp0_;
 	char** fields;
 	gint i;
 	char* val;
-	char* _tmp3;
-	const char* _tmp2;
-	DVBSatelliteChannel* _tmp4;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (line != NULL, NULL);
 	channel = dvb_satellite_channel_new ();
 	dvb_channel_set_GroupId ((DVBChannel*) channel, self->priv->_GroupId);
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	fields = (_tmp1 = _tmp0 = g_strsplit (line, ":", 0), fields_length1 = _vala_array_length (_tmp0), fields_size = fields_length1, _tmp1);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	fields = (_tmp1_ = _tmp0_ = g_strsplit (line, ":", 0), fields_length1 = _vala_array_length (_tmp0_), fields_size = fields_length1, _tmp1_);
 	i = 0;
 	val = NULL;
-	_tmp3 = NULL;
-	_tmp2 = NULL;
-	while ((val = (_tmp3 = (_tmp2 = fields[i], (_tmp2 == NULL) ? NULL : g_strdup (_tmp2)), val = (g_free (val), NULL), _tmp3)) != NULL) {
+	while (TRUE) {
+		char* _tmp3_;
+		const char* _tmp2_;
+		_tmp3_ = NULL;
+		_tmp2_ = NULL;
+		if (!((val = (_tmp3_ = (_tmp2_ = fields[i], (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_)), val = (g_free (val), NULL), _tmp3_)) != NULL)) {
+			break;
+		}
 		if (i == 0) {
 			if (g_utf8_validate (val, -1, NULL)) {
 				dvb_channel_set_Name ((DVBChannel*) channel, val);
@@ -443,8 +662,10 @@ static DVBSatelliteChannel* dvb_channel_list_reader_parse_satellite_channel (DVB
 		}
 		i++;
 	}
-	_tmp4 = NULL;
-	return (_tmp4 = channel, fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), val = (g_free (val), NULL), _tmp4);
+	result = channel;
+	fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL);
+	val = (g_free (val), NULL);
+	return result;
 }
 
 
@@ -454,30 +675,34 @@ static DVBSatelliteChannel* dvb_channel_list_reader_parse_satellite_channel (DVB
          * ProSieben:330000000:INVERSION_AUTO:6900000:FEC_NONE:QAM_64:255:256:898
          */
 static DVBCableChannel* dvb_channel_list_reader_parse_cable_channel (DVBChannelListReader* self, const char* line) {
+	DVBCableChannel* result;
 	DVBCableChannel* channel;
-	char** _tmp1;
+	char** _tmp1_;
 	gint fields_size;
 	gint fields_length1;
-	char** _tmp0;
+	char** _tmp0_;
 	char** fields;
 	gint i;
 	char* val;
 	gboolean failed;
-	char* _tmp3;
-	const char* _tmp2;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (line != NULL, NULL);
 	channel = dvb_cable_channel_new ();
 	dvb_channel_set_GroupId ((DVBChannel*) channel, self->priv->_GroupId);
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	fields = (_tmp1 = _tmp0 = g_strsplit (line, ":", 0), fields_length1 = _vala_array_length (_tmp0), fields_size = fields_length1, _tmp1);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	fields = (_tmp1_ = _tmp0_ = g_strsplit (line, ":", 0), fields_length1 = _vala_array_length (_tmp0_), fields_size = fields_length1, _tmp1_);
 	i = 0;
 	val = NULL;
 	failed = FALSE;
-	_tmp3 = NULL;
-	_tmp2 = NULL;
-	while ((val = (_tmp3 = (_tmp2 = fields[i], (_tmp2 == NULL) ? NULL : g_strdup (_tmp2)), val = (g_free (val), NULL), _tmp3)) != NULL) {
+	while (TRUE) {
+		char* _tmp3_;
+		const char* _tmp2_;
+		_tmp3_ = NULL;
+		_tmp2_ = NULL;
+		if (!((val = (_tmp3_ = (_tmp2_ = fields[i], (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_)), val = (g_free (val), NULL), _tmp3_)) != NULL)) {
+			break;
+		}
 		if (i == 0) {
 			if (g_utf8_validate (val, -1, NULL)) {
 				dvb_channel_set_Name ((DVBChannel*) channel, val);
@@ -500,7 +725,7 @@ static DVBCableChannel* dvb_channel_list_reader_parse_cable_channel (DVBChannelL
 					}
 				} else {
 					if (i == 3) {
-						dvb_cable_channel_set_SymbolRate (channel, (guint) atoi (val));
+						dvb_cable_channel_set_SymbolRate (channel, (guint) (atoi (val) / 1000));
 					} else {
 						if (i == 4) {
 							gint eval;
@@ -542,13 +767,16 @@ static DVBCableChannel* dvb_channel_list_reader_parse_cable_channel (DVBChannelL
 		i++;
 	}
 	if (failed) {
-		DVBCableChannel* _tmp4;
-		_tmp4 = NULL;
-		return (_tmp4 = NULL, (channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL)), fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), val = (g_free (val), NULL), _tmp4);
+		result = NULL;
+		(channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL));
+		fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL);
+		val = (g_free (val), NULL);
+		return result;
 	} else {
-		DVBCableChannel* _tmp5;
-		_tmp5 = NULL;
-		return (_tmp5 = channel, fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), val = (g_free (val), NULL), _tmp5);
+		result = channel;
+		fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL);
+		val = (g_free (val), NULL);
+		return result;
 	}
 	(channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL));
 	fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL);
@@ -557,35 +785,41 @@ static DVBCableChannel* dvb_channel_list_reader_parse_cable_channel (DVBChannelL
 
 
 static gboolean dvb_channel_list_reader_get_value_with_prefix (GType enumtype, const char* name, const char* prefix, gint* val) {
-	char* _tmp0;
-	gboolean _tmp1;
+	gboolean result;
+	char* _tmp0_;
+	gboolean _tmp1_;
 	g_return_val_if_fail (name != NULL, FALSE);
 	g_return_val_if_fail (prefix != NULL, FALSE);
-	_tmp0 = NULL;
-	return (_tmp1 = dvb_utils_get_value_by_name_from_enum (enumtype, _tmp0 = g_strconcat (prefix, name, NULL), &(*val)), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+	_tmp0_ = NULL;
+	result = (_tmp1_ = dvb_utils_get_value_by_name_from_enum (enumtype, _tmp0_ = g_strconcat (prefix, name, NULL), &(*val)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	return result;
 }
 
 
 GFile* dvb_channel_list_reader_get_ChannelFile (DVBChannelListReader* self) {
+	GFile* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_ChannelFile;
+	result = self->priv->_ChannelFile;
+	return result;
 }
 
 
 static void dvb_channel_list_reader_set_ChannelFile (DVBChannelListReader* self, GFile* value) {
-	GFile* _tmp2;
-	GFile* _tmp1;
+	GFile* _tmp1_;
+	GFile* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_ChannelFile = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_ChannelFile == NULL) ? NULL : (self->priv->_ChannelFile = (g_object_unref (self->priv->_ChannelFile), NULL)), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_ChannelFile = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_object_ref (_tmp0_)), (self->priv->_ChannelFile == NULL) ? NULL : (self->priv->_ChannelFile = (g_object_unref (self->priv->_ChannelFile), NULL)), _tmp1_);
 	g_object_notify ((GObject *) self, "ChannelFile");
 }
 
 
 DVBAdapterType dvb_channel_list_reader_get_Type (DVBChannelListReader* self) {
+	DVBAdapterType result;
 	g_return_val_if_fail (self != NULL, 0);
-	return self->priv->_Type;
+	result = self->priv->_Type;
+	return result;
 }
 
 
@@ -597,8 +831,10 @@ static void dvb_channel_list_reader_set_Type (DVBChannelListReader* self, DVBAda
 
 
 guint dvb_channel_list_reader_get_GroupId (DVBChannelListReader* self) {
+	guint result;
 	g_return_val_if_fail (self != NULL, 0U);
-	return self->priv->_GroupId;
+	result = self->priv->_GroupId;
+	return result;
 }
 
 
@@ -609,6 +845,41 @@ static void dvb_channel_list_reader_set_GroupId (DVBChannelListReader* self, gui
 }
 
 
+static void dvb_channel_list_reader_class_init (DVBChannelListReaderClass * klass) {
+	dvb_channel_list_reader_parent_class = g_type_class_peek_parent (klass);
+	g_type_class_add_private (klass, sizeof (DVBChannelListReaderPrivate));
+	G_OBJECT_CLASS (klass)->get_property = dvb_channel_list_reader_get_property;
+	G_OBJECT_CLASS (klass)->set_property = dvb_channel_list_reader_set_property;
+	G_OBJECT_CLASS (klass)->finalize = dvb_channel_list_reader_finalize;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_CHANNEL_LIST_READER_CHANNEL_FILE, g_param_spec_object ("ChannelFile", "ChannelFile", "ChannelFile", G_TYPE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_CHANNEL_LIST_READER_TYPE, g_param_spec_enum ("Type", "Type", "Type", DVB_TYPE_ADAPTER_TYPE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_CHANNEL_LIST_READER_GROUP_ID, g_param_spec_uint ("GroupId", "GroupId", "GroupId", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+}
+
+
+static void dvb_channel_list_reader_instance_init (DVBChannelListReader * self) {
+	self->priv = DVB_CHANNEL_LIST_READER_GET_PRIVATE (self);
+}
+
+
+static void dvb_channel_list_reader_finalize (GObject* obj) {
+	DVBChannelListReader * self;
+	self = DVB_CHANNEL_LIST_READER (obj);
+	(self->priv->_ChannelFile == NULL) ? NULL : (self->priv->_ChannelFile = (g_object_unref (self->priv->_ChannelFile), NULL));
+	G_OBJECT_CLASS (dvb_channel_list_reader_parent_class)->finalize (obj);
+}
+
+
+GType dvb_channel_list_reader_get_type (void) {
+	static GType dvb_channel_list_reader_type_id = 0;
+	if (dvb_channel_list_reader_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (DVBChannelListReaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dvb_channel_list_reader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DVBChannelListReader), 0, (GInstanceInitFunc) dvb_channel_list_reader_instance_init, NULL };
+		dvb_channel_list_reader_type_id = g_type_register_static (G_TYPE_OBJECT, "DVBChannelListReader", &g_define_type_info, 0);
+	}
+	return dvb_channel_list_reader_type_id;
+}
+
+
 static void dvb_channel_list_reader_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	DVBChannelListReader * self;
 	gpointer boxed;
@@ -650,42 +921,7 @@ static void dvb_channel_list_reader_set_property (GObject * object, guint proper
 }
 
 
-static void dvb_channel_list_reader_class_init (DVBChannelListReaderClass * klass) {
-	dvb_channel_list_reader_parent_class = g_type_class_peek_parent (klass);
-	g_type_class_add_private (klass, sizeof (DVBChannelListReaderPrivate));
-	G_OBJECT_CLASS (klass)->get_property = dvb_channel_list_reader_get_property;
-	G_OBJECT_CLASS (klass)->set_property = dvb_channel_list_reader_set_property;
-	G_OBJECT_CLASS (klass)->finalize = dvb_channel_list_reader_finalize;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_CHANNEL_LIST_READER_CHANNEL_FILE, g_param_spec_object ("ChannelFile", "ChannelFile", "ChannelFile", G_TYPE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_CHANNEL_LIST_READER_TYPE, g_param_spec_enum ("Type", "Type", "Type", DVB_TYPE_ADAPTER_TYPE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_CHANNEL_LIST_READER_GROUP_ID, g_param_spec_uint ("GroupId", "GroupId", "GroupId", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-}
-
-
-static void dvb_channel_list_reader_instance_init (DVBChannelListReader * self) {
-	self->priv = DVB_CHANNEL_LIST_READER_GET_PRIVATE (self);
-}
-
-
-static void dvb_channel_list_reader_finalize (GObject* obj) {
-	DVBChannelListReader * self;
-	self = DVB_CHANNEL_LIST_READER (obj);
-	(self->priv->_ChannelFile == NULL) ? NULL : (self->priv->_ChannelFile = (g_object_unref (self->priv->_ChannelFile), NULL));
-	G_OBJECT_CLASS (dvb_channel_list_reader_parent_class)->finalize (obj);
-}
-
-
-GType dvb_channel_list_reader_get_type (void) {
-	static GType dvb_channel_list_reader_type_id = 0;
-	if (dvb_channel_list_reader_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (DVBChannelListReaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dvb_channel_list_reader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DVBChannelListReader), 0, (GInstanceInitFunc) dvb_channel_list_reader_instance_init, NULL };
-		dvb_channel_list_reader_type_id = g_type_register_static (G_TYPE_OBJECT, "DVBChannelListReader", &g_define_type_info, 0);
-	}
-	return dvb_channel_list_reader_type_id;
-}
-
-
-static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
 		for (i = 0; i < array_length; i = i + 1) {
@@ -694,6 +930,11 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 			}
 		}
 	}
+}
+
+
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+	_vala_array_destroy (array, array_length, destroy_func);
 	g_free (array);
 }
 
