@@ -200,7 +200,7 @@ static void _g_slist_free_dvb_event_teletext_component_unref (GSList* self);
 #define DVB_EVENT_RUNNING_STATUS_RUNNING ((guint) 4)
 DVBEvent* dvb_event_new (void);
 DVBEvent* dvb_event_construct (GType object_type);
-static gint64 dvb_event_get_end_timestamp (DVBEvent* self);
+static time_t dvb_event_get_end_timestamp (DVBEvent* self);
 gboolean dvb_event_has_expired (DVBEvent* self);
 struct tm dvb_event_get_utc_start_time (DVBEvent* self);
 gboolean dvb_event_is_running (DVBEvent* self);
@@ -287,15 +287,15 @@ gboolean dvb_event_has_expired (DVBEvent* self) {
 	time_t _tmp0_ = {0};
 	struct tm _tmp1_ = {0};
 	struct tm current_utc;
-	gint64 current_time;
-	gint64 end_timestamp;
+	time_t current_time;
+	time_t end_timestamp;
 	g_return_val_if_fail (self != NULL, FALSE);
 	current_utc = (gmtime_r ((_tmp2_ = (time (&_tmp0_), _tmp0_), &_tmp2_), &_tmp1_), _tmp1_);
 	/* set day light saving time to undefined
 	 otherwise mktime will add an hour,
 	 because it respects dst*/
 	current_utc.tm_isdst = -1;
-	current_time = (gint64) mktime (&current_utc);
+	current_time = mktime (&current_utc);
 	end_timestamp = dvb_event_get_end_timestamp (self);
 	result = end_timestamp < current_time;
 	return result;
@@ -309,13 +309,13 @@ gboolean dvb_event_is_running (DVBEvent* self) {
 	struct tm _tmp1_ = {0};
 	struct tm time_now;
 	struct tm time_start;
-	gint64 timestamp_now;
-	gint64 timestamp_start;
+	time_t timestamp_now;
+	time_t timestamp_start;
 	g_return_val_if_fail (self != NULL, FALSE);
 	time_now = (gmtime_r ((_tmp2_ = (time (&_tmp0_), _tmp0_), &_tmp2_), &_tmp1_), _tmp1_);
 	time_start = dvb_event_get_utc_start_time (self);
-	timestamp_now = (gint64) timegm (&time_now);
-	timestamp_start = (gint64) timegm (&time_start);
+	timestamp_now = timegm (&time_now);
+	timestamp_start = timegm (&time_start);
 	if ((timestamp_now - timestamp_start) >= 0) {
 		/* Has started, check if it's still running*/
 		result = !dvb_event_has_expired (self);
@@ -394,16 +394,15 @@ struct tm dvb_event_get_utc_start_time (DVBEvent* self) {
 /**
          * @returns: UNIX time stamp
          */
-static gint64 dvb_event_get_end_timestamp (DVBEvent* self) {
-	gint64 result;
+static time_t dvb_event_get_end_timestamp (DVBEvent* self) {
+	time_t result;
 	struct tm end_time;
-	gint64 before;
-	gint64 after;
-	g_return_val_if_fail (self != NULL, 0LL);
+	time_t before;
+	time_t after;
 	end_time = dvb_utils_create_utc_time ((gint) self->year, (gint) self->month, (gint) self->day, (gint) self->hour, (gint) self->minute, (gint) self->second);
-	before = (gint64) mktime (&end_time);
+	before = mktime (&end_time);
 	end_time.tm_sec = end_time.tm_sec + ((gint) self->duration);
-	after = (gint64) mktime (&end_time);
+	after = mktime (&end_time);
 	g_assert ((after - before) == self->duration);
 	result = after;
 	return result;
@@ -419,8 +418,8 @@ static gint64 dvb_event_get_end_timestamp (DVBEvent* self) {
 gint dvb_event_compare (DVBEvent* event1, DVBEvent* event2) {
 	gint result;
 	gboolean _tmp0_;
-	gint64 event1_time;
-	gint64 event2_time;
+	time_t event1_time;
+	time_t event2_time;
 	_tmp0_ = FALSE;
 	if (event1 == NULL) {
 		_tmp0_ = event2 == NULL;
