@@ -24,6 +24,7 @@
 #include <gio/gio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <cstuff.h>
 
 
 #define DVB_TYPE_SCANNER (dvb_scanner_get_type ())
@@ -112,13 +113,18 @@ struct _DVBScannerClass {
 struct _DVBScannerPrivate {
 	DVBDevice* _Device;
 	GeeArrayList* new_channels;
-	guint check_for_lock_event_id;
-	guint wait_for_tables_event_id;
+	GSource* check_for_lock_source;
+	GSource* wait_for_tables_source;
 	gboolean nit_arrived;
 	gboolean sdt_arrived;
 	gboolean pat_arrived;
 	gboolean pmt_arrived;
 	gboolean locked;
+	GMainContext* context;
+	GMainLoop* loop;
+	GThread* worker_thread;
+	gboolean running;
+	guint bus_watch_id;
 };
 
 
@@ -145,14 +151,17 @@ DVBChannel* dvb_scanner_get_new_channel (DVBScanner* self);
 static DVBChannel* dvb_scanner_real_get_new_channel (DVBScanner* self);
 void dvb_scanner_add_values_from_structure_to_channel (DVBScanner* self, const GstStructure* delivery, DVBChannel* channel);
 static void dvb_scanner_real_add_values_from_structure_to_channel (DVBScanner* self, const GstStructure* delivery, DVBChannel* channel);
+static void* dvb_scanner_worker (DVBScanner* self);
+static void* _dvb_scanner_worker_gthread_func (gpointer self);
 DVBChannelList* dvb_channel_list_new (GFile* channels);
 DVBChannelList* dvb_channel_list_construct (GType object_type, GFile* channels);
 DVBDevice* dvb_scanner_get_Device (DVBScanner* self);
 guint dvb_device_get_Adapter (DVBDevice* self);
 guint dvb_device_get_Frontend (DVBDevice* self);
-void dvb_scanner_bus_watch_func (DVBScanner* self, GstBus* bus, GstMessage* message);
-static void _dvb_scanner_bus_watch_func_gst_bus_message (GstBus* _sender, GstMessage* message, gpointer self);
-void dvb_scanner_start_scan (DVBScanner* self);
+gboolean dvb_scanner_bus_watch_func (DVBScanner* self, GstBus* bus, GstMessage* message);
+static gboolean _dvb_scanner_bus_watch_func_gst_bus_func (GstBus* bus, GstMessage* message, gpointer self);
+gboolean dvb_scanner_start_scan (DVBScanner* self);
+static gboolean _dvb_scanner_start_scan_gsource_func (gpointer self);
 void dvb_scanner_Run (DVBScanner* self);
 void dvb_scanner_remove_check_for_lock_timeout (DVBScanner* self);
 void dvb_scanner_remove_wait_for_tables_timeout (DVBScanner* self);
@@ -173,6 +182,7 @@ void dvb_scanner_add_structure_to_scan (DVBScanner* self, GstStructure* structur
 void dvb_channel_list_remove (DVBChannelList* self, guint sid);
 gboolean dvb_scanner_check_for_lock (DVBScanner* self);
 static gboolean _dvb_scanner_check_for_lock_gsource_func (gpointer self);
+void dvb_scanner_queue_start_scan (DVBScanner* self);
 gboolean dvb_scanner_wait_for_tables (DVBScanner* self);
 void dvb_scanner_set_uint_property (GstElement* src, const GstStructure* params, const char* key);
 static gboolean _dvb_scanner_wait_for_tables_gsource_func (gpointer self);
@@ -201,6 +211,7 @@ const char* dvb_channel_get_Network (DVBChannel* self);
 gboolean dvb_channel_get_Scrambled (DVBChannel* self);
 void dvb_channel_set_Sid (DVBChannel* self, guint value);
 void dvb_channel_list_add (DVBChannelList* self, DVBChannel* channel);
+DVBScanner* dvb_scanner_construct (GType object_type);
 static void dvb_scanner_set_Device (DVBScanner* self, DVBDevice* value);
 DVBChannelList* dvb_scanner_get_Channels (DVBScanner* self);
 guint dvb_scanned_item_hash (DVBScannedItem* o);
@@ -278,8 +289,18 @@ void dvb_scanner_add_values_from_structure_to_channel (DVBScanner* self, const G
 }
 
 
-static void _dvb_scanner_bus_watch_func_gst_bus_message (GstBus* _sender, GstMessage* message, gpointer self) {
-	dvb_scanner_bus_watch_func (self, _sender, message);
+static void* _dvb_scanner_worker_gthread_func (gpointer self) {
+	return dvb_scanner_worker (self);
+}
+
+
+static gboolean _dvb_scanner_bus_watch_func_gst_bus_func (GstBus* bus, GstMessage* message, gpointer self) {
+	return dvb_scanner_bus_watch_func (self, bus, message);
+}
+
+
+static gboolean _dvb_scanner_start_scan_gsource_func (gpointer self) {
+	return dvb_scanner_start_scan (self);
 }
 
 
@@ -288,26 +309,42 @@ static void _dvb_scanner_bus_watch_func_gst_bus_message (GstBus* _sender, GstMes
          */
 void dvb_scanner_Run (DVBScanner* self) {
 	GError * _inner_error_;
-	DVBChannelList* _tmp0_;
+	GMainLoop* _tmp0_;
+	GThread* _tmp1_;
+	DVBChannelList* _tmp2_;
 	GstBus* bus;
+	GSource* source;
 	g_return_if_fail (self != NULL);
 	_inner_error_ = NULL;
+	if (self->priv->running) {
+		return;
+	}
+	self->priv->running = TRUE;
 	_tmp0_ = NULL;
-	self->channels = (_tmp0_ = dvb_channel_list_new (NULL), (self->channels == NULL) ? NULL : (self->channels = (g_object_unref (self->channels), NULL)), _tmp0_);
+	self->priv->loop = (_tmp0_ = g_main_loop_new (self->priv->context, FALSE), (self->priv->loop == NULL) ? NULL : (self->priv->loop = (g_main_loop_unref (self->priv->loop), NULL)), _tmp0_);
+	_tmp1_ = g_thread_create (_dvb_scanner_worker_gthread_func, self, TRUE, &_inner_error_);
+	if (_inner_error_ != NULL) {
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
+		g_clear_error (&_inner_error_);
+		return;
+	}
+	self->priv->worker_thread = _tmp1_;
+	_tmp2_ = NULL;
+	self->channels = (_tmp2_ = dvb_channel_list_new (NULL), (self->channels == NULL) ? NULL : (self->channels = (g_object_unref (self->channels), NULL)), _tmp2_);
 	{
-		char* _tmp1_;
-		GstElement* _tmp2_;
-		GstElement* _tmp3_;
+		char* _tmp3_;
 		GstElement* _tmp4_;
-		_tmp1_ = NULL;
-		_tmp2_ = NULL;
-		_tmp3_ = (_tmp2_ = gst_parse_launch (_tmp1_ = g_strdup_printf (DVB_SCANNER_PIPELINE_TEMPLATE, dvb_device_get_Adapter (self->priv->_Device), dvb_device_get_Frontend (self->priv->_Device), DVB_SCANNER_BASE_PIDS), &_inner_error_), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
+		GstElement* _tmp5_;
+		GstElement* _tmp6_;
+		_tmp3_ = NULL;
+		_tmp4_ = NULL;
+		_tmp5_ = (_tmp4_ = gst_parse_launch (_tmp3_ = g_strdup_printf (DVB_SCANNER_PIPELINE_TEMPLATE, dvb_device_get_Adapter (self->priv->_Device), dvb_device_get_Frontend (self->priv->_Device), DVB_SCANNER_BASE_PIDS), &_inner_error_), _tmp3_ = (g_free (_tmp3_), NULL), _tmp4_);
 		if (_inner_error_ != NULL) {
 			goto __catch20_g_error;
 			goto __finally20;
 		}
-		_tmp4_ = NULL;
-		self->pipeline = (_tmp4_ = _tmp3_, (self->pipeline == NULL) ? NULL : (self->pipeline = (gst_object_unref (self->pipeline), NULL)), _tmp4_);
+		_tmp6_ = NULL;
+		self->pipeline = (_tmp6_ = _tmp5_, (self->pipeline == NULL) ? NULL : (self->pipeline = (gst_object_unref (self->pipeline), NULL)), _tmp6_);
 	}
 	goto __finally20;
 	__catch20_g_error:
@@ -316,7 +353,7 @@ void dvb_scanner_Run (DVBScanner* self) {
 		e = _inner_error_;
 		_inner_error_ = NULL;
 		{
-			g_error ("Scanner.vala:147: Could not create pipeline: %s", e->message);
+			g_error ("Scanner.vala:160: Could not create pipeline: %s", e->message);
 			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 			return;
 		}
@@ -328,11 +365,13 @@ void dvb_scanner_Run (DVBScanner* self) {
 		return;
 	}
 	bus = gst_element_get_bus (self->pipeline);
-	gst_bus_add_signal_watch (bus);
-	g_signal_connect_object (bus, "message", (GCallback) _dvb_scanner_bus_watch_func_gst_bus_message, self, 0);
+	self->priv->bus_watch_id = gst_bus_add_watch_context (bus, _dvb_scanner_bus_watch_func_gst_bus_func, self, self->priv->context);
 	gst_element_set_state (self->pipeline, GST_STATE_READY);
-	dvb_scanner_start_scan (self);
+	source = g_idle_source_new ();
+	g_source_set_callback (source, _dvb_scanner_start_scan_gsource_func, g_object_ref (self), g_object_unref);
+	g_source_attach (source, self->priv->context);
 	(bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL));
+	(source == NULL) ? NULL : (source = (g_source_unref (source), NULL));
 }
 
 
@@ -349,6 +388,14 @@ void dvb_scanner_Destroy (DVBScanner* self) {
 	_tmp0_ = NULL;
 	self->channels = (_tmp0_ = NULL, (self->channels == NULL) ? NULL : (self->channels = (g_object_unref (self->channels), NULL)), _tmp0_);
 	g_signal_emit_by_name (self, "destroyed");
+	if (self->priv->loop != NULL) {
+		GMainLoop* _tmp1_;
+		g_main_loop_quit (self->priv->loop);
+		_tmp1_ = NULL;
+		self->priv->loop = (_tmp1_ = NULL, (self->priv->loop == NULL) ? NULL : (self->priv->loop = (g_main_loop_unref (self->priv->loop), NULL)), _tmp1_);
+		g_thread_join (self->priv->worker_thread);
+		self->priv->worker_thread = NULL;
+	}
 }
 
 
@@ -394,7 +441,7 @@ gboolean dvb_scanner_WriteAllChannelsToFile (DVBScanner* self, const char* path)
 				e = _inner_error_;
 				_inner_error_ = NULL;
 				{
-					g_critical ("Scanner.vala:184: Could not write to file: %s", e->message);
+					g_critical ("Scanner.vala:206: Could not write to file: %s", e->message);
 					success = FALSE;
 					(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 				}
@@ -426,7 +473,7 @@ gboolean dvb_scanner_WriteAllChannelsToFile (DVBScanner* self, const char* path)
 		e = _inner_error_;
 		_inner_error_ = NULL;
 		{
-			g_critical ("Scanner.vala:192: Could not close file handle: %s", e->message);
+			g_critical ("Scanner.vala:214: Could not close file handle: %s", e->message);
 			success = FALSE;
 			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 		}
@@ -477,7 +524,7 @@ gboolean dvb_scanner_WriteChannelsToFile (DVBScanner* self, guint* channel_sids,
 				DVBChannel* c;
 				c = dvb_channel_list_get_channel (self->channels, sid);
 				if (c == NULL) {
-					g_warning ("Scanner.vala:211: Channel with SID %u does not exist", sid);
+					g_warning ("Scanner.vala:233: Channel with SID %u does not exist", sid);
 					(c == NULL) ? NULL : (c = (g_object_unref (c), NULL));
 					continue;
 				}
@@ -495,7 +542,7 @@ gboolean dvb_scanner_WriteChannelsToFile (DVBScanner* self, guint* channel_sids,
 					e = _inner_error_;
 					_inner_error_ = NULL;
 					{
-						g_critical ("Scanner.vala:217: Could not write to file: %s", e->message);
+						g_critical ("Scanner.vala:239: Could not write to file: %s", e->message);
 						success = FALSE;
 						(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 					}
@@ -526,7 +573,7 @@ gboolean dvb_scanner_WriteChannelsToFile (DVBScanner* self, guint* channel_sids,
 		e = _inner_error_;
 		_inner_error_ = NULL;
 		{
-			g_critical ("Scanner.vala:225: Could not close file handle: %s", e->message);
+			g_critical ("Scanner.vala:247: Could not close file handle: %s", e->message);
 			success = FALSE;
 			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 		}
@@ -544,26 +591,42 @@ gboolean dvb_scanner_WriteChannelsToFile (DVBScanner* self, guint* channel_sids,
 }
 
 
+/* Main Thread */
+static void* dvb_scanner_worker (DVBScanner* self) {
+	void* result;
+	g_return_val_if_fail (self != NULL, NULL);
+	g_main_loop_run (self->priv->loop);
+	result = NULL;
+	return result;
+}
+
+
 void dvb_scanner_clear_and_reset_all (DVBScanner* self) {
-	GstStructure* _tmp1_;
+	GstStructure* _tmp2_;
 	g_return_if_fail (self != NULL);
 	if (self->pipeline != NULL) {
-		GstBus* bus;
-		GstElement* _tmp0_;
-		bus = gst_element_get_bus (self->pipeline);
-		gst_bus_remove_signal_watch (bus);
+		GSource* _tmp0_;
+		GSource* bus_watch_source;
+		GstElement* _tmp1_;
+		_tmp0_ = NULL;
+		bus_watch_source = (_tmp0_ = g_main_context_find_source_by_id (self->priv->context, self->priv->bus_watch_id), (_tmp0_ == NULL) ? NULL : g_source_ref (_tmp0_));
+		if (bus_watch_source != NULL) {
+			g_source_destroy (bus_watch_source);
+			self->priv->bus_watch_id = (guint) 0;
+		}
 		gst_element_set_state (self->pipeline, GST_STATE_NULL);
 		/* Free pipeline*/
-		_tmp0_ = NULL;
-		self->pipeline = (_tmp0_ = NULL, (self->pipeline == NULL) ? NULL : (self->pipeline = (gst_object_unref (self->pipeline), NULL)), _tmp0_);
-		(bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL));
+		_tmp1_ = NULL;
+		self->pipeline = (_tmp1_ = NULL, (self->pipeline == NULL) ? NULL : (self->pipeline = (gst_object_unref (self->pipeline), NULL)), _tmp1_);
+		(bus_watch_source == NULL) ? NULL : (bus_watch_source = (g_source_unref (bus_watch_source), NULL));
 	}
-	gee_map_clear ((GeeMap*) self->transport_streams);
-	gee_collection_clear ((GeeCollection*) self->scanned_frequencies);
+	gee_abstract_map_clear ((GeeAbstractMap*) self->transport_streams);
+	gee_abstract_collection_clear ((GeeAbstractCollection*) self->scanned_frequencies);
 	dvb_scanner_clear_frequencies (self);
-	_tmp1_ = NULL;
-	self->current_tuning_params = (_tmp1_ = NULL, (self->current_tuning_params == NULL) ? NULL : (self->current_tuning_params = (gst_structure_free (self->current_tuning_params), NULL)), _tmp1_);
-	gee_collection_clear ((GeeCollection*) self->priv->new_channels);
+	_tmp2_ = NULL;
+	self->current_tuning_params = (_tmp2_ = NULL, (self->current_tuning_params == NULL) ? NULL : (self->current_tuning_params = (gst_structure_free (self->current_tuning_params), NULL)), _tmp2_);
+	gee_abstract_collection_clear ((GeeAbstractCollection*) self->priv->new_channels);
+	self->priv->running = FALSE;
 }
 
 
@@ -594,12 +657,12 @@ void dvb_scanner_add_structure_to_scan (DVBScanner* self, GstStructure* structur
 		return;
 	}
 	item = dvb_scanner_get_scanned_item (self, structure);
-	if (!gee_collection_contains ((GeeCollection*) self->scanned_frequencies, item)) {
+	if (!gee_abstract_collection_contains ((GeeAbstractCollection*) self->scanned_frequencies, item)) {
 		const GstStructure* _tmp0_;
-		g_debug ("Scanner.vala:263: Queueing new frequency %u", dvb_scanned_item_get_Frequency (item));
+		g_debug ("Scanner.vala:297: Queueing new frequency %u", dvb_scanned_item_get_Frequency (item));
 		_tmp0_ = NULL;
 		g_queue_push_tail (self->frequencies, (_tmp0_ = structure, (_tmp0_ == NULL) ? NULL : gst_structure_copy (_tmp0_)));
-		gee_collection_add ((GeeCollection*) self->scanned_frequencies, item);
+		gee_abstract_collection_add ((GeeAbstractCollection*) self->scanned_frequencies, item);
 	}
 	(item == NULL) ? NULL : (item = (g_object_unref (item), NULL));
 	(structure == NULL) ? NULL : (structure = (gst_structure_free (structure), NULL));
@@ -627,7 +690,8 @@ static gboolean _dvb_scanner_check_for_lock_gsource_func (gpointer self) {
          * Pick up the next tuning paramters from the queue
          * and start scanning with them
          */
-void dvb_scanner_start_scan (DVBScanner* self) {
+gboolean dvb_scanner_start_scan (DVBScanner* self) {
+	gboolean result;
 	gboolean _tmp0_;
 	gboolean _tmp1_;
 	gboolean _tmp2_;
@@ -640,7 +704,8 @@ void dvb_scanner_start_scan (DVBScanner* self) {
 	GstStructure* _tmp8_;
 	guint freq;
 	GstElement* dvbsrc;
-	g_return_if_fail (self != NULL);
+	GSource* _tmp9_;
+	g_return_val_if_fail (self != NULL, FALSE);
 	_tmp0_ = FALSE;
 	_tmp1_ = FALSE;
 	_tmp2_ = FALSE;
@@ -665,7 +730,7 @@ void dvb_scanner_start_scan (DVBScanner* self) {
 	_tmp5_ = NULL;
 	_tmp4_ = NULL;
 	_tmp3_ = NULL;
-	g_debug ("Scanner.vala:276: Received all tables: %s (pat: %s, sdt: %s, nit: %s, pmt: %s)", _tmp3_ = bool_to_string (all_tables), _tmp4_ = bool_to_string (self->priv->pat_arrived), _tmp5_ = bool_to_string (self->priv->sdt_arrived), _tmp6_ = bool_to_string (self->priv->nit_arrived), _tmp7_ = bool_to_string (self->priv->pmt_arrived));
+	g_debug ("Scanner.vala:310: Received all tables: %s (pat: %s, sdt: %s, nit: %s, pmt: %s)", _tmp3_ = bool_to_string (all_tables), _tmp4_ = bool_to_string (self->priv->pat_arrived), _tmp5_ = bool_to_string (self->priv->sdt_arrived), _tmp6_ = bool_to_string (self->priv->nit_arrived), _tmp7_ = bool_to_string (self->priv->pmt_arrived));
 	_tmp7_ = (g_free (_tmp7_), NULL);
 	_tmp6_ = (g_free (_tmp6_), NULL);
 	_tmp5_ = (g_free (_tmp5_), NULL);
@@ -683,13 +748,13 @@ void dvb_scanner_start_scan (DVBScanner* self) {
 		g_signal_emit_by_name (self, "frequency-scanned", old_freq, self->frequencies->length);
 	}
 	if (g_queue_is_empty (self->frequencies)) {
-		g_message ("Scanner.vala:294: Finished scanning");
+		g_message ("Scanner.vala:328: Finished scanning");
 		/* We don't have all the information for those channels
 		 remove them*/
-		g_debug ("Scanner.vala:297: %u channels still have missing or invalid information", (guint) gee_collection_get_size ((GeeCollection*) self->priv->new_channels));
+		g_debug ("Scanner.vala:331: %u channels still have missing or invalid information", (guint) gee_collection_get_size ((GeeCollection*) self->priv->new_channels));
 		{
 			GeeIterator* _sid_it;
-			_sid_it = gee_iterable_iterator ((GeeIterable*) self->priv->new_channels);
+			_sid_it = gee_abstract_collection_iterator ((GeeAbstractCollection*) self->priv->new_channels);
 			while (TRUE) {
 				guint sid;
 				if (!gee_iterator_next (_sid_it)) {
@@ -702,22 +767,28 @@ void dvb_scanner_start_scan (DVBScanner* self) {
 		}
 		dvb_scanner_clear_and_reset_all (self);
 		g_signal_emit_by_name (self, "finished");
-		return;
+		result = FALSE;
+		return result;
 	}
 	_tmp8_ = NULL;
 	self->current_tuning_params = (_tmp8_ = (GstStructure*) g_queue_pop_head (self->frequencies), (self->current_tuning_params == NULL) ? NULL : (self->current_tuning_params = (gst_structure_free (self->current_tuning_params), NULL)), _tmp8_);
 	/* Remember that we already scanned this frequency*/
 	freq = 0U;
 	gst_structure_get_uint (self->current_tuning_params, "frequency", &freq);
-	g_debug ("Scanner.vala:313: Starting scanning frequency %u (%u left)", freq, g_queue_get_length (self->frequencies));
+	g_debug ("Scanner.vala:347: Starting scanning frequency %u (%u left)", freq, g_queue_get_length (self->frequencies));
 	gst_element_set_state (self->pipeline, GST_STATE_READY);
 	dvb_scanner_prepare (self);
 	/* Reset PIDs*/
 	dvbsrc = gst_bin_get_by_name (GST_BIN (self->pipeline), "dvbsrc");
 	g_object_set ((GObject*) dvbsrc, "pids", DVB_SCANNER_BASE_PIDS, NULL);
+	_tmp9_ = NULL;
+	self->priv->check_for_lock_source = (_tmp9_ = g_timeout_source_new_seconds ((guint) 5), (self->priv->check_for_lock_source == NULL) ? NULL : (self->priv->check_for_lock_source = (g_source_unref (self->priv->check_for_lock_source), NULL)), _tmp9_);
+	g_source_set_callback (self->priv->check_for_lock_source, _dvb_scanner_check_for_lock_gsource_func, g_object_ref (self), g_object_unref);
+	g_source_attach (self->priv->check_for_lock_source, self->priv->context);
 	gst_element_set_state (self->pipeline, GST_STATE_PLAYING);
-	self->priv->check_for_lock_event_id = g_timeout_add_seconds ((guint) 5, _dvb_scanner_check_for_lock_gsource_func, self);
+	result = FALSE;
 	(dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL));
+	return result;
 }
 
 
@@ -728,10 +799,9 @@ void dvb_scanner_start_scan (DVBScanner* self) {
 gboolean dvb_scanner_check_for_lock (DVBScanner* self) {
 	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	self->priv->check_for_lock_event_id = (guint) 0;
 	if (!self->priv->locked) {
 		gst_element_set_state (self->pipeline, GST_STATE_READY);
-		dvb_scanner_start_scan (self);
+		dvb_scanner_queue_start_scan (self);
 	}
 	result = FALSE;
 	return result;
@@ -744,7 +814,6 @@ gboolean dvb_scanner_wait_for_tables (DVBScanner* self) {
 	gboolean _tmp1_;
 	gboolean _tmp2_;
 	g_return_val_if_fail (self != NULL, FALSE);
-	self->priv->wait_for_tables_event_id = (guint) 0;
 	_tmp0_ = FALSE;
 	_tmp1_ = FALSE;
 	_tmp2_ = FALSE;
@@ -765,7 +834,7 @@ gboolean dvb_scanner_wait_for_tables (DVBScanner* self) {
 	}
 	if (!_tmp0_) {
 		gst_element_set_state (self->pipeline, GST_STATE_READY);
-		dvb_scanner_start_scan (self);
+		dvb_scanner_queue_start_scan (self);
 	}
 	result = FALSE;
 	return result;
@@ -774,22 +843,36 @@ gboolean dvb_scanner_wait_for_tables (DVBScanner* self) {
 
 void dvb_scanner_remove_check_for_lock_timeout (DVBScanner* self) {
 	g_return_if_fail (self != NULL);
-	if (self->priv->check_for_lock_event_id != 0) {
-		g_source_remove (self->priv->check_for_lock_event_id);
-		self->priv->check_for_lock_event_id = (guint) 0;
+	if (self->priv->check_for_lock_source != NULL) {
+		GSource* _tmp0_;
+		g_source_destroy (self->priv->check_for_lock_source);
+		_tmp0_ = NULL;
+		self->priv->check_for_lock_source = (_tmp0_ = NULL, (self->priv->check_for_lock_source == NULL) ? NULL : (self->priv->check_for_lock_source = (g_source_unref (self->priv->check_for_lock_source), NULL)), _tmp0_);
 	}
 }
 
 
 void dvb_scanner_remove_wait_for_tables_timeout (DVBScanner* self) {
 	g_return_if_fail (self != NULL);
-	if (self->priv->wait_for_tables_event_id != 0) {
-		g_source_remove (self->priv->wait_for_tables_event_id);
-		self->priv->wait_for_tables_event_id = (guint) 0;
+	if (self->priv->wait_for_tables_source != NULL) {
+		GSource* _tmp0_;
+		g_source_destroy (self->priv->wait_for_tables_source);
+		_tmp0_ = NULL;
+		self->priv->wait_for_tables_source = (_tmp0_ = NULL, (self->priv->wait_for_tables_source == NULL) ? NULL : (self->priv->wait_for_tables_source = (g_source_unref (self->priv->wait_for_tables_source), NULL)), _tmp0_);
 	}
 }
 
 
+void dvb_scanner_queue_start_scan (DVBScanner* self) {
+	GSource* source;
+	g_return_if_fail (self != NULL);
+	source = g_idle_source_new ();
+	g_source_set_callback (source, _dvb_scanner_start_scan_gsource_func, g_object_ref (self), g_object_unref);
+	g_source_attach (source, self->priv->context);
+	(source == NULL) ? NULL : (source = (g_source_unref (source), NULL));
+}
+
+
 void dvb_scanner_set_uint_property (GstElement* src, const GstStructure* params, const char* key) {
 	guint val;
 	g_return_if_fail (src != NULL);
@@ -820,16 +903,20 @@ void dvb_scanner_on_dvb_frontend_stats_structure (DVBScanner* self, const GstStr
 		_tmp0_ = FALSE;
 	}
 	if (_tmp0_) {
-		g_debug ("Scanner.vala:378: Got lock");
+		GSource* _tmp1_;
+		g_debug ("Scanner.vala:420: Got lock");
 		dvb_scanner_remove_check_for_lock_timeout (self);
-		self->priv->wait_for_tables_event_id = g_timeout_add_seconds ((guint) 10, _dvb_scanner_wait_for_tables_gsource_func, self);
+		_tmp1_ = NULL;
+		self->priv->wait_for_tables_source = (_tmp1_ = g_timeout_source_new_seconds ((guint) 10), (self->priv->wait_for_tables_source == NULL) ? NULL : (self->priv->wait_for_tables_source = (g_source_unref (self->priv->wait_for_tables_source), NULL)), _tmp1_);
+		g_source_set_callback (self->priv->wait_for_tables_source, _dvb_scanner_wait_for_tables_gsource_func, g_object_ref (self), g_object_unref);
+		g_source_attach (self->priv->wait_for_tables_source, self->priv->context);
 	}
 }
 
 
 void dvb_scanner_on_dvb_read_failure_structure (DVBScanner* self) {
 	g_return_if_fail (self != NULL);
-	g_warning ("Scanner.vala:386: Read failure");
+	g_warning ("Scanner.vala:430: Read failure");
 }
 
 
@@ -869,7 +956,7 @@ void dvb_scanner_on_pat_structure (DVBScanner* self, const GstStructure* structu
 	GstElement* dvbsrc;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (structure != NULL);
-	g_debug ("Scanner.vala:393: Received PAT");
+	g_debug ("Scanner.vala:437: Received PAT");
 	pid_set = (GeeSet*) gee_hash_set_new (G_TYPE_UINT, NULL, NULL, g_direct_hash, g_direct_equal);
 	/* add BASE_PIDS*/
 	gee_collection_add ((GeeCollection*) pid_set, GUINT_TO_POINTER ((guint) 16));
@@ -923,7 +1010,7 @@ void dvb_scanner_on_pat_structure (DVBScanner* self, const GstStructure* structu
 		(_pid_it == NULL) ? NULL : (_pid_it = (g_object_unref (_pid_it), NULL));
 	}
 	pids = string_substring (new_pids->str, (glong) 0, new_pids->len - 1);
-	g_debug ("Scanner.vala:425: Setting %d pids: %s", gee_collection_get_size ((GeeCollection*) pid_set), pids);
+	g_debug ("Scanner.vala:469: Setting %d pids: %s", gee_collection_get_size ((GeeCollection*) pid_set), pids);
 	/* We want to parse the pmt as well*/
 	dvbsrc = gst_bin_get_by_name (GST_BIN (self->pipeline), "dvbsrc");
 	g_object_set ((GObject*) dvbsrc, "pids", pids, NULL);
@@ -996,7 +1083,7 @@ void dvb_scanner_on_sdt_structure (DVBScanner* self, const GstStructure* structu
 	const GstStructure* service;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (structure != NULL);
-	g_debug ("Scanner.vala:434: Received SDT");
+	g_debug ("Scanner.vala:478: Received SDT");
 	tsid = 0U;
 	gst_structure_get_uint (structure, "transport-stream-id", &tsid);
 	services = *gst_structure_get_value (structure, "services");
@@ -1091,7 +1178,7 @@ void dvb_scanner_on_nit_structure (DVBScanner* self, const GstStructure* structu
 	const GstStructure* transport;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (structure != NULL);
-	g_debug ("Scanner.vala:488: Received NIT");
+	g_debug ("Scanner.vala:532: Received NIT");
 	name = NULL;
 	if (gst_structure_has_field (structure, "network-name")) {
 		char* _tmp1_;
@@ -1107,7 +1194,7 @@ void dvb_scanner_on_nit_structure (DVBScanner* self, const GstStructure* structu
 		_tmp2_ = NULL;
 		name = (_tmp2_ = g_strdup_printf ("%u", nid), name = (g_free (name), NULL), _tmp2_);
 	}
-	g_debug ("Scanner.vala:498: Network name '%s'", name);
+	g_debug ("Scanner.vala:542: Network name '%s'", name);
 	transports = *gst_structure_get_value (structure, "transports");
 	size = gst_value_list_get_size (&transports);
 	transport = NULL;
@@ -1138,8 +1225,8 @@ void dvb_scanner_on_nit_structure (DVBScanner* self, const GstStructure* structu
 					const GstStructure* _tmp4_;
 					delivery_val = *gst_structure_get_value (transport, "delivery");
 					delivery = gst_value_get_structure (&delivery_val);
-					g_debug ("Scanner.vala:517: Received TS %u", tsid);
-					gee_map_set ((GeeMap*) self->transport_streams, GUINT_TO_POINTER (tsid), delivery);
+					g_debug ("Scanner.vala:561: Received TS %u", tsid);
+					gee_abstract_map_set ((GeeAbstractMap*) self->transport_streams, GUINT_TO_POINTER (tsid), delivery);
 					freq = 0U;
 					gst_structure_get_uint (delivery, "frequency", &freq);
 					/* Takes care of duplicates*/
@@ -1210,7 +1297,7 @@ void dvb_scanner_on_pmt_structure (DVBScanner* self, const GstStructure* structu
 	const GstStructure* stream;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (structure != NULL);
-	g_debug ("Scanner.vala:563: Received PMT");
+	g_debug ("Scanner.vala:607: Received PMT");
 	program_number = 0U;
 	gst_structure_get_uint (structure, "program-number", &program_number);
 	if (!dvb_channel_list_contains (self->channels, program_number)) {
@@ -1249,7 +1336,7 @@ void dvb_scanner_on_pmt_structure (DVBScanner* self, const GstStructure* structu
 					case 0x02:
 					case 0x1b:
 					{
-						g_debug ("Scanner.vala:595: Found video PID %u for channel %u", pid, program_number);
+						g_debug ("Scanner.vala:639: Found video PID %u for channel %u", pid, program_number);
 						dvb_channel_set_VideoPID (dvb_channel, pid);
 						break;
 					}
@@ -1258,13 +1345,13 @@ void dvb_scanner_on_pmt_structure (DVBScanner* self, const GstStructure* structu
 					case 0x0f:
 					case 0x11:
 					{
-						g_debug ("Scanner.vala:603: Found audio PID %u for channel %u", pid, program_number);
+						g_debug ("Scanner.vala:647: Found audio PID %u for channel %u", pid, program_number);
 						gee_collection_add ((GeeCollection*) dvb_channel_get_AudioPIDs (dvb_channel), GUINT_TO_POINTER (pid));
 						break;
 					}
 					default:
 					{
-						g_debug ("Scanner.vala:608: Other stream type: 0x%02x", stream_type);
+						g_debug ("Scanner.vala:652: Other stream type: 0x%02x", stream_type);
 						break;
 					}
 				}
@@ -1276,14 +1363,15 @@ void dvb_scanner_on_pmt_structure (DVBScanner* self, const GstStructure* structu
 }
 
 
-void dvb_scanner_bus_watch_func (DVBScanner* self, GstBus* bus, GstMessage* message) {
+gboolean dvb_scanner_bus_watch_func (DVBScanner* self, GstBus* bus, GstMessage* message) {
+	gboolean result;
 	gboolean _tmp4_;
 	gboolean _tmp10_;
 	gboolean _tmp11_;
 	gboolean _tmp12_;
-	g_return_if_fail (self != NULL);
-	g_return_if_fail (bus != NULL);
-	g_return_if_fail (message != NULL);
+	g_return_val_if_fail (self != NULL, FALSE);
+	g_return_val_if_fail (bus != NULL, FALSE);
+	g_return_val_if_fail (message != NULL, FALSE);
 	switch (message->type) {
 		case GST_MESSAGE_ELEMENT:
 		{
@@ -1331,11 +1419,12 @@ void dvb_scanner_bus_watch_func (DVBScanner* self, GstBus* bus, GstMessage* mess
 				_tmp0_ = NULL;
 				(gst_message_parse_error (message, &_tmp0_, &_tmp2_), gerror = (_tmp1_ = _tmp0_, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp1_));
 				debug = (_tmp3_ = _tmp2_, debug = (g_free (debug), NULL), _tmp3_);
-				g_critical ("Scanner.vala:637: %s %s", gerror->message, debug);
+				g_critical ("Scanner.vala:681: %s %s", gerror->message, debug);
 				dvb_scanner_Destroy (self);
+				result = FALSE;
 				(gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL));
 				debug = (g_free (debug), NULL);
-				break;
+				return result;
 			}
 		}
 	}
@@ -1349,7 +1438,7 @@ void dvb_scanner_bus_watch_func (DVBScanner* self, GstBus* bus, GstMessage* mess
 	if (_tmp4_) {
 		{
 			GeeIterator* _sid_it;
-			_sid_it = gee_iterable_iterator ((GeeIterable*) self->priv->new_channels);
+			_sid_it = gee_abstract_collection_iterator ((GeeAbstractCollection*) self->priv->new_channels);
 			while (TRUE) {
 				guint sid;
 				DVBChannel* channel;
@@ -1361,14 +1450,14 @@ void dvb_scanner_bus_watch_func (DVBScanner* self, GstBus* bus, GstMessage* mess
 				channel = dvb_channel_list_get_channel (self->channels, sid);
 				tsid = dvb_channel_get_TransportStreamId (channel);
 				/* Check if already came across the transport stream*/
-				if (gee_map_contains ((GeeMap*) self->transport_streams, GUINT_TO_POINTER (tsid))) {
+				if (gee_abstract_map_contains ((GeeAbstractMap*) self->transport_streams, GUINT_TO_POINTER (tsid))) {
 					GstStructure* _tmp5_;
 					/* add values from Gst.Structure to Channel*/
 					_tmp5_ = NULL;
-					dvb_scanner_add_values_from_structure_to_channel (self, _tmp5_ = (GstStructure*) gee_map_get ((GeeMap*) self->transport_streams, GUINT_TO_POINTER (tsid)), channel);
+					dvb_scanner_add_values_from_structure_to_channel (self, _tmp5_ = (GstStructure*) gee_abstract_map_get ((GeeAbstractMap*) self->transport_streams, GUINT_TO_POINTER (tsid)), channel);
 					(_tmp5_ == NULL) ? NULL : (_tmp5_ = (gst_structure_free (_tmp5_), NULL));
 				} else {
-					g_debug ("Scanner.vala:656: TS %u for channel %u does not exist", tsid, sid);
+					g_debug ("Scanner.vala:700: TS %u for channel %u does not exist", tsid, sid);
 					/* We haven't seen the transport stream, yet
 					 Maybe it comes with a later bus message*/
 					self->priv->nit_arrived = FALSE;
@@ -1383,7 +1472,7 @@ void dvb_scanner_bus_watch_func (DVBScanner* self, GstBus* bus, GstMessage* mess
 			del_channels = gee_array_list_new (G_TYPE_UINT, NULL, NULL, g_direct_equal);
 			{
 				GeeIterator* _sid_it;
-				_sid_it = gee_iterable_iterator ((GeeIterable*) self->priv->new_channels);
+				_sid_it = gee_abstract_collection_iterator ((GeeAbstractCollection*) self->priv->new_channels);
 				while (TRUE) {
 					guint sid;
 					DVBChannel* channel;
@@ -1408,16 +1497,16 @@ void dvb_scanner_bus_watch_func (DVBScanner* self, GstBus* bus, GstMessage* mess
 						_tmp7_ = NULL;
 						type = (_tmp7_ = _tmp6_, (_tmp7_ == NULL) ? NULL : g_strdup (_tmp7_));
 						_tmp8_ = NULL;
-						g_debug ("Scanner.vala:674: Channel added: %s", _tmp8_ = dvb_channel_to_string (channel));
+						g_debug ("Scanner.vala:718: Channel added: %s", _tmp8_ = dvb_channel_to_string (channel));
 						_tmp8_ = (g_free (_tmp8_), NULL);
 						g_signal_emit_by_name (self, "channel-added", dvb_channel_get_Frequency (channel), sid, dvb_channel_get_Name (channel), dvb_channel_get_Network (channel), type, dvb_channel_get_Scrambled (channel));
 						/* Mark channel for deletion of this.new_channels*/
-						gee_collection_add ((GeeCollection*) del_channels, GUINT_TO_POINTER (sid));
+						gee_abstract_collection_add ((GeeAbstractCollection*) del_channels, GUINT_TO_POINTER (sid));
 						type = (g_free (type), NULL);
 					} else {
 						char* _tmp9_;
 						_tmp9_ = NULL;
-						g_debug ("Scanner.vala:681: Channel %u is not valid: %s", sid, _tmp9_ = dvb_channel_to_string (channel));
+						g_debug ("Scanner.vala:725: Channel %u is not valid: %s", sid, _tmp9_ = dvb_channel_to_string (channel));
 						_tmp9_ = (g_free (_tmp9_), NULL);
 						self->priv->pmt_arrived = FALSE;
 					}
@@ -1429,7 +1518,7 @@ void dvb_scanner_bus_watch_func (DVBScanner* self, GstBus* bus, GstMessage* mess
 			{
 				GeeIterator* _sid_it;
 				/* Only remove those channels we have all the information for*/
-				_sid_it = gee_iterable_iterator ((GeeIterable*) del_channels);
+				_sid_it = gee_abstract_collection_iterator ((GeeAbstractCollection*) del_channels);
 				/* Only remove those channels we have all the information for*/
 				while (TRUE) {
 					guint sid;
@@ -1440,7 +1529,7 @@ void dvb_scanner_bus_watch_func (DVBScanner* self, GstBus* bus, GstMessage* mess
 					}
 					/* Only remove those channels we have all the information for*/
 					sid = GPOINTER_TO_UINT (gee_iterator_get (_sid_it));
-					gee_collection_remove ((GeeCollection*) self->priv->new_channels, GUINT_TO_POINTER (sid));
+					gee_abstract_collection_remove ((GeeAbstractCollection*) self->priv->new_channels, GUINT_TO_POINTER (sid));
 				}
 				(_sid_it == NULL) ? NULL : (_sid_it = (g_object_unref (_sid_it), NULL));
 			}
@@ -1469,23 +1558,35 @@ void dvb_scanner_bus_watch_func (DVBScanner* self, GstBus* bus, GstMessage* mess
 	 the next frequency*/
 	if (_tmp10_) {
 		dvb_scanner_remove_wait_for_tables_timeout (self);
-		dvb_scanner_start_scan (self);
+		dvb_scanner_queue_start_scan (self);
 	}
+	result = TRUE;
+	return result;
 }
 
 
 void dvb_scanner_add_new_channel (DVBScanner* self, guint sid) {
 	DVBChannel* new_channel;
 	g_return_if_fail (self != NULL);
-	g_debug ("Scanner.vala:705: Adding new channel with SID %u", sid);
+	g_debug ("Scanner.vala:751: Adding new channel with SID %u", sid);
 	new_channel = dvb_scanner_get_new_channel (self);
 	dvb_channel_set_Sid (new_channel, sid);
 	dvb_channel_list_add (self->channels, new_channel);
-	gee_collection_add ((GeeCollection*) self->priv->new_channels, GUINT_TO_POINTER (sid));
+	gee_abstract_collection_add ((GeeAbstractCollection*) self->priv->new_channels, GUINT_TO_POINTER (sid));
 	(new_channel == NULL) ? NULL : (new_channel = (g_object_unref (new_channel), NULL));
 }
 
 
+/**
+     * An abstract class responsible for scanning for new channels
+     */
+DVBScanner* dvb_scanner_construct (GType object_type) {
+	DVBScanner * self;
+	self = g_object_newv (object_type, 0, NULL);
+	return self;
+}
+
+
 DVBDevice* dvb_scanner_get_Device (DVBScanner* self) {
 	DVBDevice* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -1537,6 +1638,7 @@ static GObject * dvb_scanner_constructor (GType type, guint n_construct_properti
 		GeeArrayList* _tmp1_;
 		GQueue* _tmp2_;
 		GeeHashMap* _tmp3_;
+		GMainContext* _tmp4_;
 		_tmp0_ = NULL;
 		self->scanned_frequencies = (_tmp0_ = gee_hash_set_new (DVB_TYPE_SCANNED_ITEM, (GBoxedCopyFunc) g_object_ref, g_object_unref, _dvb_scanned_item_hash_ghash_func, _dvb_scanned_item_equal_gequal_func), (self->scanned_frequencies == NULL) ? NULL : (self->scanned_frequencies = (g_object_unref (self->scanned_frequencies), NULL)), _tmp0_);
 		_tmp1_ = NULL;
@@ -1545,6 +1647,9 @@ static GObject * dvb_scanner_constructor (GType type, guint n_construct_properti
 		self->frequencies = (_tmp2_ = g_queue_new (), (self->frequencies == NULL) ? NULL : (self->frequencies = (g_queue_free (self->frequencies), NULL)), _tmp2_);
 		_tmp3_ = NULL;
 		self->transport_streams = (_tmp3_ = gee_hash_map_new (G_TYPE_UINT, NULL, NULL, G_TYPE_POINTER, (GBoxedCopyFunc) gst_structure_copy, gst_structure_free, g_direct_hash, g_direct_equal, g_direct_equal), (self->transport_streams == NULL) ? NULL : (self->transport_streams = (g_object_unref (self->transport_streams), NULL)), _tmp3_);
+		_tmp4_ = NULL;
+		self->priv->context = (_tmp4_ = g_main_context_new (), (self->priv->context == NULL) ? NULL : (self->priv->context = (g_main_context_unref (self->priv->context), NULL)), _tmp4_);
+		self->priv->running = FALSE;
 	}
 	return obj;
 }
@@ -1586,6 +1691,10 @@ static void dvb_scanner_finalize (GObject* obj) {
 	(self->scanned_frequencies == NULL) ? NULL : (self->scanned_frequencies = (g_object_unref (self->scanned_frequencies), NULL));
 	(self->transport_streams == NULL) ? NULL : (self->transport_streams = (g_object_unref (self->transport_streams), NULL));
 	(self->priv->new_channels == NULL) ? NULL : (self->priv->new_channels = (g_object_unref (self->priv->new_channels), NULL));
+	(self->priv->check_for_lock_source == NULL) ? NULL : (self->priv->check_for_lock_source = (g_source_unref (self->priv->check_for_lock_source), NULL));
+	(self->priv->wait_for_tables_source == NULL) ? NULL : (self->priv->wait_for_tables_source = (g_source_unref (self->priv->wait_for_tables_source), NULL));
+	(self->priv->context == NULL) ? NULL : (self->priv->context = (g_main_context_unref (self->priv->context), NULL));
+	(self->priv->loop == NULL) ? NULL : (self->priv->loop = (g_main_loop_unref (self->priv->loop), NULL));
 	G_OBJECT_CLASS (dvb_scanner_parent_class)->finalize (obj);
 }
 
