@@ -322,7 +322,7 @@ gboolean dvb_settings_save (DVBSettings* self) {
 	_tmp3_ = NULL;
 	data = (_tmp3_ = g_key_file_to_data (self->priv->keyfile, &data_len, NULL), data = (g_free (data), NULL), _tmp3_);
 	{
-		g_output_stream_write ((GOutputStream*) stream, data, data_len, NULL, &_inner_error_);
+		g_output_stream_write_all ((GOutputStream*) stream, data, data_len, NULL, NULL, &_inner_error_);
 		if (_inner_error_ != NULL) {
 			goto __catch31_g_error;
 			goto __finally31;
@@ -493,7 +493,7 @@ char** dvb_settings_get_string_list (DVBSettings* self, const char* group_name,
 	char** _tmp2_;
 	gint _tmp1__size;
 	gint _tmp1__length1;
-	gint _tmp0_;
+	gsize _tmp0_;
 	char** _tmp1_;
 	char** _tmp3_;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -524,7 +524,7 @@ gboolean* dvb_settings_get_boolean_list (DVBSettings* self, const char* group_na
 	gboolean* _tmp2_;
 	gint _tmp1__size;
 	gint _tmp1__length1;
-	gint _tmp0_;
+	gsize _tmp0_;
 	gboolean* _tmp1_;
 	gboolean* _tmp3_;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -555,7 +555,7 @@ gint* dvb_settings_get_integer_list (DVBSettings* self, const char* group_name,
 	gint* _tmp2_;
 	gint _tmp1__size;
 	gint _tmp1__length1;
-	gint _tmp0_;
+	gsize _tmp0_;
 	gint* _tmp1_;
 	gint* _tmp3_;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -586,7 +586,7 @@ double* dvb_settings_get_double_list (DVBSettings* self, const char* group_name,
 	double* _tmp2_;
 	gint _tmp1__size;
 	gint _tmp1__length1;
-	gint _tmp0_;
+	gsize _tmp0_;
 	double* _tmp1_;
 	double* _tmp3_;
 	g_return_val_if_fail (self != NULL, NULL);
