@@ -171,7 +171,7 @@ enum  {
 };
 #define DVB_SQLITE_CONFIG_TIMERS_STORE_CREATE_DEVICE_GROUPS "CREATE TABLE device_groups (\n        group_id INTEGER,\n        adapter_type INTEGER(1),\n        channels_file VARCHAR(255),\n        recordings_dir VARCHAR(255),\n        name VARCHAR(255),\n        PRIMARY KEY(group_id))"
 #define DVB_SQLITE_CONFIG_TIMERS_STORE_CREATE_DEVICES "CREATE TABLE devices (\n        group_id INTEGER,\n        adapter INTEGER,\n        frontend INTEGER,\n        PRIMARY KEY(adapter, frontend))"
-#define DVB_SQLITE_CONFIG_TIMERS_STORE_CREATE_TIMERS "CREATE TABLE timers (\n        timer_id INTEGER,\n        group_id INTEGER,\n        channel_sid INTEGER,\n        year INTEGER,\n        month INTEGER,\n        day INTEGER,\n        hour INTEGER,\n        minute INTEGER,\n        duration INTEGER,\n        PRIMARY KEY(timer_id))"
+#define DVB_SQLITE_CONFIG_TIMERS_STORE_CREATE_TIMERS "CREATE TABLE timers (\n        timer_id INTEGER,\n        group_id INTEGER,\n        channel_sid INTEGER,\n        year INTEGER,\n        month INTEGER,\n        day INTEGER,\n        hour INTEGER,\n        minute INTEGER,\n        duration INTEGER,\n        event_id INTEGER,\n        PRIMARY KEY(timer_id))"
 #define DVB_SQLITE_CONFIG_TIMERS_STORE_SELECT_ALL_GROUPS "SELECT * FROM device_groups"
 #define DVB_SQLITE_CONFIG_TIMERS_STORE_SELECT_DEVICES "SELECT * FROM devices WHERE group_id=?"
 #define DVB_SQLITE_CONFIG_TIMERS_STORE_DELETE_GROUP "DELETE FROM device_groups WHERE group_id=?"
@@ -183,7 +183,7 @@ enum  {
 #define DVB_SQLITE_CONFIG_TIMERS_STORE_INSERT_DEVICE "INSERT INTO devices VALUES (?, ?, ?)"
 #define DVB_SQLITE_CONFIG_TIMERS_STORE_SELECT_TIMERS "SELECT * FROM timers WHERE group_id=?"
 #define DVB_SQLITE_CONFIG_TIMERS_STORE_DELETE_TIMER "DELETE FROM timers WHERE timer_id=?"
-#define DVB_SQLITE_CONFIG_TIMERS_STORE_INSERT_TIMER "INSERT INTO timers VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)"
+#define DVB_SQLITE_CONFIG_TIMERS_STORE_INSERT_TIMER "INSERT INTO timers VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)"
 #define DVB_SQLITE_CONFIG_TIMERS_STORE_CONTAINS_TIMER "SELECT COUNT(*) FROM timers WHERE timer_id=?"
 static void dvb_sqlite_config_timers_store_print_last_error (DVBSqliteConfigTimersStore* self);
 DVBDevice* dvb_device_new (guint adapter, guint frontend, gboolean get_type_and_name);
@@ -217,6 +217,7 @@ GType dvb_channel_get_type (void);
 DVBChannel* dvb_channel_list_get_channel (DVBChannelList* self, guint sid);
 DVBTimer* dvb_timer_new (guint32 id, DVBChannel* channel, gint year, gint month, gint day, gint hour, gint minute, guint duration, const char* name);
 DVBTimer* dvb_timer_construct (GType object_type, guint32 id, DVBChannel* channel, gint year, gint month, gint day, gint hour, gint minute, guint duration, const char* name);
+void dvb_timer_set_EventID (DVBTimer* self, guint value);
 static GeeList* dvb_sqlite_config_timers_store_real_get_all_timers_of_device_group (DVBTimersStore* base, DVBDeviceGroup* dev);
 gboolean dvb_sqlite_config_timers_store_contains_timer (DVBSqliteConfigTimersStore* self, guint timer_id);
 guint32 dvb_timer_get_Id (DVBTimer* self);
@@ -228,6 +229,7 @@ guint dvb_timer_get_Day (DVBTimer* self);
 guint dvb_timer_get_Hour (DVBTimer* self);
 guint dvb_timer_get_Minute (DVBTimer* self);
 guint dvb_timer_get_Duration (DVBTimer* self);
+guint dvb_timer_get_EventID (DVBTimer* self);
 static gboolean dvb_sqlite_config_timers_store_real_add_timer_to_device_group (DVBTimersStore* base, DVBTimer* timer, DVBDeviceGroup* dev);
 static gboolean dvb_sqlite_config_timers_store_real_remove_timer_from_device_group (DVBTimersStore* base, guint timer_id, DVBDeviceGroup* dev);
 static gboolean dvb_sqlite_config_timers_store_real_update_from_group (DVBConfigStore* base, DVBDeviceGroup* devgroup);
@@ -298,7 +300,7 @@ static GeeList* dvb_sqlite_config_timers_store_real_get_all_device_groups (DVBCo
 		}
 		/* No devices for this group*/
 		if (gee_collection_get_size ((GeeCollection*) devs) == 0) {
-			g_debug ("SqliteConfigTimersStore.vala:174: Group %d has no devices", group_id);
+			g_debug ("SqliteConfigTimersStore.vala:175: Group %d has no devices", group_id);
 			(devs == NULL) ? NULL : (devs = (g_object_unref (devs), NULL));
 			continue;
 		}
@@ -323,7 +325,7 @@ static GeeList* dvb_sqlite_config_timers_store_real_get_all_device_groups (DVBCo
 			}
 			default:
 			{
-				g_debug ("SqliteConfigTimersStore.vala:186: Group %d has unknown type %d", group_id, group_type);
+				g_debug ("SqliteConfigTimersStore.vala:187: Group %d has unknown type %d", group_id, group_type);
 				continue;
 			}
 		}
@@ -348,7 +350,7 @@ static GeeList* dvb_sqlite_config_timers_store_real_get_all_device_groups (DVBCo
 			e = _inner_error_;
 			_inner_error_ = NULL;
 			{
-				g_warning ("SqliteConfigTimersStore.vala:199: Could not read channels: %s", e->message);
+				g_warning ("SqliteConfigTimersStore.vala:200: Could not read channels: %s", e->message);
 				(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 				(devs == NULL) ? NULL : (devs = (g_object_unref (devs), NULL));
 				(channels_file == NULL) ? NULL : (channels_file = (g_object_unref (channels_file), NULL));
@@ -629,19 +631,21 @@ static GeeList* dvb_sqlite_config_timers_store_real_get_all_timers_of_device_gro
 		guint tid;
 		guint sid;
 		guint duration;
+		guint event_id;
 		gint year;
 		gint month;
 		gint day;
 		gint hour;
 		gint minute;
 		DVBChannel* channel;
-		DVBTimer* _tmp0_;
+		DVBTimer* timer;
 		if (!(sqlite3_step (self->priv->select_timers_statement) == SQLITE_ROW)) {
 			break;
 		}
 		tid = 0U;
 		sid = 0U;
 		duration = 0U;
+		event_id = 0U;
 		year = 0;
 		month = 0;
 		day = 0;
@@ -655,11 +659,13 @@ static GeeList* dvb_sqlite_config_timers_store_real_get_all_timers_of_device_gro
 		hour = sqlite3_column_int (self->priv->select_timers_statement, 6);
 		minute = sqlite3_column_int (self->priv->select_timers_statement, 7);
 		duration = (guint) sqlite3_column_int (self->priv->select_timers_statement, 8);
+		event_id = (guint) sqlite3_column_int (self->priv->select_timers_statement, 9);
 		channel = dvb_channel_list_get_channel (dvb_device_group_get_Channels (dev), sid);
-		_tmp0_ = NULL;
-		gee_collection_add ((GeeCollection*) timers, _tmp0_ = dvb_timer_new ((guint32) tid, channel, year, month, day, hour, minute, duration, NULL));
-		(_tmp0_ == NULL) ? NULL : (_tmp0_ = (g_object_unref (_tmp0_), NULL));
+		timer = dvb_timer_new ((guint32) tid, channel, year, month, day, hour, minute, duration, NULL);
+		dvb_timer_set_EventID (timer, event_id);
+		gee_collection_add ((GeeCollection*) timers, timer);
 		(channel == NULL) ? NULL : (channel = (g_object_unref (channel), NULL));
+		(timer == NULL) ? NULL : (timer = (g_object_unref (timer), NULL));
 	}
 	result = timers;
 	return result;
@@ -677,6 +683,7 @@ static gboolean dvb_sqlite_config_timers_store_real_add_timer_to_device_group (D
 	gboolean _tmp5_;
 	gboolean _tmp6_;
 	gboolean _tmp7_;
+	gboolean _tmp8_;
 	self = (DVBSqliteConfigTimersStore*) base;
 	g_return_val_if_fail (timer != NULL, FALSE);
 	g_return_val_if_fail (dev != NULL, FALSE);
@@ -693,45 +700,51 @@ static gboolean dvb_sqlite_config_timers_store_real_add_timer_to_device_group (D
 	_tmp5_ = FALSE;
 	_tmp6_ = FALSE;
 	_tmp7_ = FALSE;
+	_tmp8_ = FALSE;
 	if (sqlite3_bind_int (self->priv->insert_timer_statement, 1, (gint) dvb_timer_get_Id (timer)) != SQLITE_OK) {
+		_tmp8_ = TRUE;
+	} else {
+		_tmp8_ = sqlite3_bind_int (self->priv->insert_timer_statement, 2, (gint) dvb_device_group_get_Id (dev)) != SQLITE_OK;
+	}
+	if (_tmp8_) {
 		_tmp7_ = TRUE;
 	} else {
-		_tmp7_ = sqlite3_bind_int (self->priv->insert_timer_statement, 2, (gint) dvb_device_group_get_Id (dev)) != SQLITE_OK;
+		_tmp7_ = sqlite3_bind_int (self->priv->insert_timer_statement, 3, (gint) dvb_channel_get_Sid (dvb_timer_get_Channel (timer))) != SQLITE_OK;
 	}
 	if (_tmp7_) {
 		_tmp6_ = TRUE;
 	} else {
-		_tmp6_ = sqlite3_bind_int (self->priv->insert_timer_statement, 3, (gint) dvb_channel_get_Sid (dvb_timer_get_Channel (timer))) != SQLITE_OK;
+		_tmp6_ = sqlite3_bind_int (self->priv->insert_timer_statement, 4, (gint) dvb_timer_get_Year (timer)) != SQLITE_OK;
 	}
 	if (_tmp6_) {
 		_tmp5_ = TRUE;
 	} else {
-		_tmp5_ = sqlite3_bind_int (self->priv->insert_timer_statement, 4, (gint) dvb_timer_get_Year (timer)) != SQLITE_OK;
+		_tmp5_ = sqlite3_bind_int (self->priv->insert_timer_statement, 5, (gint) dvb_timer_get_Month (timer)) != SQLITE_OK;
 	}
 	if (_tmp5_) {
 		_tmp4_ = TRUE;
 	} else {
-		_tmp4_ = sqlite3_bind_int (self->priv->insert_timer_statement, 5, (gint) dvb_timer_get_Month (timer)) != SQLITE_OK;
+		_tmp4_ = sqlite3_bind_int (self->priv->insert_timer_statement, 6, (gint) dvb_timer_get_Day (timer)) != SQLITE_OK;
 	}
 	if (_tmp4_) {
 		_tmp3_ = TRUE;
 	} else {
-		_tmp3_ = sqlite3_bind_int (self->priv->insert_timer_statement, 6, (gint) dvb_timer_get_Day (timer)) != SQLITE_OK;
+		_tmp3_ = sqlite3_bind_int (self->priv->insert_timer_statement, 7, (gint) dvb_timer_get_Hour (timer)) != SQLITE_OK;
 	}
 	if (_tmp3_) {
 		_tmp2_ = TRUE;
 	} else {
-		_tmp2_ = sqlite3_bind_int (self->priv->insert_timer_statement, 7, (gint) dvb_timer_get_Hour (timer)) != SQLITE_OK;
+		_tmp2_ = sqlite3_bind_int (self->priv->insert_timer_statement, 8, (gint) dvb_timer_get_Minute (timer)) != SQLITE_OK;
 	}
 	if (_tmp2_) {
 		_tmp1_ = TRUE;
 	} else {
-		_tmp1_ = sqlite3_bind_int (self->priv->insert_timer_statement, 8, (gint) dvb_timer_get_Minute (timer)) != SQLITE_OK;
+		_tmp1_ = sqlite3_bind_int (self->priv->insert_timer_statement, 9, (gint) dvb_timer_get_Duration (timer)) != SQLITE_OK;
 	}
 	if (_tmp1_) {
 		_tmp0_ = TRUE;
 	} else {
-		_tmp0_ = sqlite3_bind_int (self->priv->insert_timer_statement, 9, (gint) dvb_timer_get_Duration (timer)) != SQLITE_OK;
+		_tmp0_ = sqlite3_bind_int (self->priv->insert_timer_statement, 10, (gint) dvb_timer_get_EventID (timer)) != SQLITE_OK;
 	}
 	if (_tmp0_) {
 		dvb_sqlite_config_timers_store_print_last_error (self);
@@ -844,7 +857,7 @@ static gboolean dvb_sqlite_config_timers_store_real_update_from_group (DVBConfig
 
 static void dvb_sqlite_config_timers_store_print_last_error (DVBSqliteConfigTimersStore* self) {
 	g_return_if_fail (self != NULL);
-	g_critical ("SqliteConfigTimersStore.vala:434: SQLite error: %d, %s", sqlite3_errcode (self->priv->db), sqlite3_errmsg (self->priv->db));
+	g_critical ("SqliteConfigTimersStore.vala:439: SQLite error: %d, %s", sqlite3_errcode (self->priv->db), sqlite3_errmsg (self->priv->db));
 }
 
 
@@ -879,7 +892,7 @@ static sqlite3* dvb_sqlite_config_timers_store_get_db_handler (void) {
 			e = _inner_error_;
 			_inner_error_ = NULL;
 			{
-				g_critical ("SqliteConfigTimersStore.vala:448: Could not create directory: %s", e->message);
+				g_critical ("SqliteConfigTimersStore.vala:453: Could not create directory: %s", e->message);
 				result = NULL;
 				(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 				(config_dir == NULL) ? NULL : (config_dir = (g_object_unref (config_dir), NULL));
@@ -924,7 +937,7 @@ static sqlite3* dvb_sqlite_config_timers_store_get_db_handler (void) {
 		_tmp4_ = NULL;
 		val = (_tmp5_ = sqlite3_exec (db, DVB_SQLITE_CONFIG_TIMERS_STORE_CREATE_DEVICE_GROUPS, NULL, NULL, &_tmp4_), errormsg = (_tmp6_ = _tmp4_, errormsg = (g_free (errormsg), NULL), _tmp6_), _tmp5_);
 		if (val != SQLITE_OK) {
-			g_critical ("SqliteConfigTimersStore.vala:461: SQLite error: %s", errormsg);
+			g_critical ("SqliteConfigTimersStore.vala:466: SQLite error: %s", errormsg);
 			result = NULL;
 			errormsg = (g_free (errormsg), NULL);
 			(config_dir == NULL) ? NULL : (config_dir = (g_object_unref (config_dir), NULL));
@@ -937,7 +950,7 @@ static sqlite3* dvb_sqlite_config_timers_store_get_db_handler (void) {
 		_tmp7_ = NULL;
 		val = (_tmp8_ = sqlite3_exec (db, DVB_SQLITE_CONFIG_TIMERS_STORE_CREATE_DEVICES, NULL, NULL, &_tmp7_), errormsg = (_tmp9_ = _tmp7_, errormsg = (g_free (errormsg), NULL), _tmp9_), _tmp8_);
 		if (val != SQLITE_OK) {
-			g_critical ("SqliteConfigTimersStore.vala:467: SQLite error: %s", errormsg);
+			g_critical ("SqliteConfigTimersStore.vala:472: SQLite error: %s", errormsg);
 			result = NULL;
 			errormsg = (g_free (errormsg), NULL);
 			(config_dir == NULL) ? NULL : (config_dir = (g_object_unref (config_dir), NULL));
@@ -950,7 +963,7 @@ static sqlite3* dvb_sqlite_config_timers_store_get_db_handler (void) {
 		_tmp10_ = NULL;
 		val = (_tmp11_ = sqlite3_exec (db, DVB_SQLITE_CONFIG_TIMERS_STORE_CREATE_TIMERS, NULL, NULL, &_tmp10_), errormsg = (_tmp12_ = _tmp10_, errormsg = (g_free (errormsg), NULL), _tmp12_), _tmp11_);
 		if (val != SQLITE_OK) {
-			g_critical ("SqliteConfigTimersStore.vala:473: SQLite error: %s", errormsg);
+			g_critical ("SqliteConfigTimersStore.vala:478: SQLite error: %s", errormsg);
 			result = NULL;
 			errormsg = (g_free (errormsg), NULL);
 			(config_dir == NULL) ? NULL : (config_dir = (g_object_unref (config_dir), NULL));
