@@ -71,6 +71,7 @@ struct _DVBTimerPrivate {
 	guint _Minute;
 	guint _Duration;
 	GstElement* _sink;
+	guint _EventID;
 	struct tm starttime;
 };
 
@@ -98,7 +99,8 @@ enum  {
 	DVB_TIMER_HOUR,
 	DVB_TIMER_MINUTE,
 	DVB_TIMER_DURATION,
-	DVB_TIMER_SINK
+	DVB_TIMER_SINK,
+	DVB_TIMER_EVENT_ID
 };
 static void dvb_timer_set_Id (DVBTimer* self, guint32 value);
 static void dvb_timer_set_Channel (DVBTimer* self, DVBChannel* value);
@@ -108,6 +110,7 @@ void dvb_timer_set_Month (DVBTimer* self, guint value);
 void dvb_timer_set_Day (DVBTimer* self, guint value);
 void dvb_timer_set_Hour (DVBTimer* self, guint value);
 void dvb_timer_set_Minute (DVBTimer* self, guint value);
+void dvb_timer_set_EventID (DVBTimer* self, guint value);
 void dvb_timer_set_Duration (DVBTimer* self, guint value);
 struct tm dvb_utils_create_time (gint year, gint month, gint day, gint hour, gint minute, gint second);
 DVBTimer* dvb_timer_new (guint32 id, DVBChannel* channel, gint year, gint month, gint day, gint hour, gint minute, guint duration, const char* name);
@@ -141,6 +144,7 @@ guint32 dvb_timer_get_Id (DVBTimer* self);
 const char* dvb_timer_get_Name (DVBTimer* self);
 GstElement* dvb_timer_get_sink (DVBTimer* self);
 void dvb_timer_set_sink (DVBTimer* self, GstElement* value);
+guint dvb_timer_get_EventID (DVBTimer* self);
 static void dvb_timer_finalize (GObject* obj);
 static void dvb_timer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
 static void dvb_timer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
@@ -169,6 +173,7 @@ DVBTimer* dvb_timer_construct (GType object_type, guint32 id, DVBChannel* channe
 	dvb_timer_set_Day (self, (guint) day);
 	dvb_timer_set_Hour (self, (guint) hour);
 	dvb_timer_set_Minute (self, (guint) minute);
+	dvb_timer_set_EventID (self, (guint) 0);
 	dvb_timer_set_Duration (self, duration);
 	self->priv->starttime = dvb_utils_create_time (year, month, day, hour, minute, 0);
 	while (__params_it > __params) {
@@ -659,6 +664,21 @@ void dvb_timer_set_sink (DVBTimer* self, GstElement* value) {
 }
 
 
+guint dvb_timer_get_EventID (DVBTimer* self) {
+	guint result;
+	g_return_val_if_fail (self != NULL, 0U);
+	result = self->priv->_EventID;
+	return result;
+}
+
+
+void dvb_timer_set_EventID (DVBTimer* self, guint value) {
+	g_return_if_fail (self != NULL);
+	self->priv->_EventID = value;
+	g_object_notify ((GObject *) self, "EventID");
+}
+
+
 static void dvb_timer_class_init (DVBTimerClass * klass) {
 	dvb_timer_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (DVBTimerPrivate));
@@ -675,6 +695,7 @@ static void dvb_timer_class_init (DVBTimerClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_MINUTE, g_param_spec_uint ("Minute", "Minute", "Minute", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_DURATION, g_param_spec_uint ("Duration", "Duration", "Duration", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_SINK, g_param_spec_object ("sink", "sink", "sink", GST_TYPE_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_EVENT_ID, g_param_spec_uint ("EventID", "EventID", "EventID", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -738,6 +759,9 @@ static void dvb_timer_get_property (GObject * object, guint property_id, GValue
 		case DVB_TIMER_SINK:
 		g_value_set_object (value, dvb_timer_get_sink (self));
 		break;
+		case DVB_TIMER_EVENT_ID:
+		g_value_set_uint (value, dvb_timer_get_EventID (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -779,6 +803,9 @@ static void dvb_timer_set_property (GObject * object, guint property_id, const G
 		case DVB_TIMER_SINK:
 		dvb_timer_set_sink (self, g_value_get_object (value));
 		break;
+		case DVB_TIMER_EVENT_ID:
+		dvb_timer_set_EventID (self, g_value_get_uint (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
