@@ -36,7 +36,7 @@ const char* dvb_utils_get_name_by_value_from_enum (GType enumtype, gint val);
 static void _g_slist_free_g_object_unref (GSList* self);
 void dvb_utils_mkdirs (GFile* directory, GError** error);
 char* dvb_utils_remove_nonalphanums (const char* text);
-gint64 dvb_utils_difftime (const struct tm* t1, const struct tm* t2);
+time_t dvb_utils_difftime (const struct tm* t1, const struct tm* t2);
 struct tm dvb_utils_create_time (gint year, gint month, gint day, gint hour, gint minute, gint second);
 struct tm dvb_utils_create_utc_time (gint year, gint month, gint day, gint hour, gint minute, gint second);
 char* dvb_utils_read_file_contents (GFile* file, GError** error);
@@ -262,13 +262,13 @@ char* dvb_utils_remove_nonalphanums (const char* text) {
 /**
      * @returns: Difference in seconds
      */
-inline gint64 dvb_utils_difftime (const struct tm* t1, const struct tm* t2) {
-	gint64 result;
-	gint64 ts1;
-	gint64 ts2;
-	gint64 diff;
-	ts1 = (gint64) mktime (&(*t1));
-	ts2 = (gint64) mktime (&(*t2));
+inline time_t dvb_utils_difftime (const struct tm* t1, const struct tm* t2) {
+	time_t result;
+	time_t ts1;
+	time_t ts2;
+	time_t diff;
+	ts1 = mktime (&(*t1));
+	ts2 = mktime (&(*t2));
 	diff = ts1 - ts2;
 	if (diff < 0) {
 		result = (-1) * diff;
